from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.ApplicationModel.SocialInfo
import win32more.Windows.Foundation
import win32more.Windows.Foundation.Collections
import win32more.Windows.Graphics.Imaging
import win32more.Windows.Storage.Streams
import win32more.Windows.Win32.System.WinRT
class ISocialFeedChildItem(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.SocialInfo.ISocialFeedChildItem'
    _iid_ = Guid('{0b6a985a-d59d-40be-980c-488a2ab30a83}')
    @winrt_commethod(6)
    def get_Author(self) -> win32more.Windows.ApplicationModel.SocialInfo.SocialUserInfo: ...
    @winrt_commethod(7)
    def get_PrimaryContent(self) -> win32more.Windows.ApplicationModel.SocialInfo.SocialFeedContent: ...
    @winrt_commethod(8)
    def get_SecondaryContent(self) -> win32more.Windows.ApplicationModel.SocialInfo.SocialFeedContent: ...
    @winrt_commethod(9)
    def get_Timestamp(self) -> win32more.Windows.Foundation.DateTime: ...
    @winrt_commethod(10)
    def put_Timestamp(self, value: win32more.Windows.Foundation.DateTime) -> Void: ...
    @winrt_commethod(11)
    def get_TargetUri(self) -> win32more.Windows.Foundation.Uri: ...
    @winrt_commethod(12)
    def put_TargetUri(self, value: win32more.Windows.Foundation.Uri) -> Void: ...
    @winrt_commethod(13)
    def get_Thumbnails(self) -> win32more.Windows.Foundation.Collections.IVector[win32more.Windows.ApplicationModel.SocialInfo.SocialItemThumbnail]: ...
    @winrt_commethod(14)
    def get_SharedItem(self) -> win32more.Windows.ApplicationModel.SocialInfo.SocialFeedSharedItem: ...
    @winrt_commethod(15)
    def put_SharedItem(self, value: win32more.Windows.ApplicationModel.SocialInfo.SocialFeedSharedItem) -> Void: ...
    Author = property(get_Author, None)
    PrimaryContent = property(get_PrimaryContent, None)
    SecondaryContent = property(get_SecondaryContent, None)
    SharedItem = property(get_SharedItem, put_SharedItem)
    TargetUri = property(get_TargetUri, put_TargetUri)
    Thumbnails = property(get_Thumbnails, None)
    Timestamp = property(get_Timestamp, put_Timestamp)
class ISocialFeedContent(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.SocialInfo.ISocialFeedContent'
    _iid_ = Guid('{a234e429-3e39-494d-a37c-f462a2494514}')
    @winrt_commethod(6)
    def get_Title(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def put_Title(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(8)
    def get_Message(self) -> WinRT_String: ...
    @winrt_commethod(9)
    def put_Message(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(10)
    def get_TargetUri(self) -> win32more.Windows.Foundation.Uri: ...
    @winrt_commethod(11)
    def put_TargetUri(self, value: win32more.Windows.Foundation.Uri) -> Void: ...
    Message = property(get_Message, put_Message)
    TargetUri = property(get_TargetUri, put_TargetUri)
    Title = property(get_Title, put_Title)
class ISocialFeedItem(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.SocialInfo.ISocialFeedItem'
    _iid_ = Guid('{4f1392ab-1f72-4d33-b695-de3e1db60317}')
    @winrt_commethod(6)
    def get_Author(self) -> win32more.Windows.ApplicationModel.SocialInfo.SocialUserInfo: ...
    @winrt_commethod(7)
    def get_PrimaryContent(self) -> win32more.Windows.ApplicationModel.SocialInfo.SocialFeedContent: ...
    @winrt_commethod(8)
    def get_SecondaryContent(self) -> win32more.Windows.ApplicationModel.SocialInfo.SocialFeedContent: ...
    @winrt_commethod(9)
    def get_Timestamp(self) -> win32more.Windows.Foundation.DateTime: ...
    @winrt_commethod(10)
    def put_Timestamp(self, value: win32more.Windows.Foundation.DateTime) -> Void: ...
    @winrt_commethod(11)
    def get_TargetUri(self) -> win32more.Windows.Foundation.Uri: ...
    @winrt_commethod(12)
    def put_TargetUri(self, value: win32more.Windows.Foundation.Uri) -> Void: ...
    @winrt_commethod(13)
    def get_Thumbnails(self) -> win32more.Windows.Foundation.Collections.IVector[win32more.Windows.ApplicationModel.SocialInfo.SocialItemThumbnail]: ...
    @winrt_commethod(14)
    def get_SharedItem(self) -> win32more.Windows.ApplicationModel.SocialInfo.SocialFeedSharedItem: ...
    @winrt_commethod(15)
    def put_SharedItem(self, value: win32more.Windows.ApplicationModel.SocialInfo.SocialFeedSharedItem) -> Void: ...
    @winrt_commethod(16)
    def get_BadgeStyle(self) -> win32more.Windows.ApplicationModel.SocialInfo.SocialItemBadgeStyle: ...
    @winrt_commethod(17)
    def put_BadgeStyle(self, value: win32more.Windows.ApplicationModel.SocialInfo.SocialItemBadgeStyle) -> Void: ...
    @winrt_commethod(18)
    def get_BadgeCountValue(self) -> Int32: ...
    @winrt_commethod(19)
    def put_BadgeCountValue(self, value: Int32) -> Void: ...
    @winrt_commethod(20)
    def get_RemoteId(self) -> WinRT_String: ...
    @winrt_commethod(21)
    def put_RemoteId(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(22)
    def get_ChildItem(self) -> win32more.Windows.ApplicationModel.SocialInfo.SocialFeedChildItem: ...
    @winrt_commethod(23)
    def put_ChildItem(self, value: win32more.Windows.ApplicationModel.SocialInfo.SocialFeedChildItem) -> Void: ...
    @winrt_commethod(24)
    def get_Style(self) -> win32more.Windows.ApplicationModel.SocialInfo.SocialFeedItemStyle: ...
    @winrt_commethod(25)
    def put_Style(self, value: win32more.Windows.ApplicationModel.SocialInfo.SocialFeedItemStyle) -> Void: ...
    Author = property(get_Author, None)
    BadgeCountValue = property(get_BadgeCountValue, put_BadgeCountValue)
    BadgeStyle = property(get_BadgeStyle, put_BadgeStyle)
    ChildItem = property(get_ChildItem, put_ChildItem)
    PrimaryContent = property(get_PrimaryContent, None)
    RemoteId = property(get_RemoteId, put_RemoteId)
    SecondaryContent = property(get_SecondaryContent, None)
    SharedItem = property(get_SharedItem, put_SharedItem)
    Style = property(get_Style, put_Style)
    TargetUri = property(get_TargetUri, put_TargetUri)
    Thumbnails = property(get_Thumbnails, None)
    Timestamp = property(get_Timestamp, put_Timestamp)
class ISocialFeedSharedItem(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.SocialInfo.ISocialFeedSharedItem'
    _iid_ = Guid('{7bfb9e40-a6aa-45a7-9ff6-54c42105dd1f}')
    @winrt_commethod(6)
    def get_OriginalSource(self) -> win32more.Windows.Foundation.Uri: ...
    @winrt_commethod(7)
    def put_OriginalSource(self, value: win32more.Windows.Foundation.Uri) -> Void: ...
    @winrt_commethod(8)
    def get_Content(self) -> win32more.Windows.ApplicationModel.SocialInfo.SocialFeedContent: ...
    @winrt_commethod(9)
    def get_Timestamp(self) -> win32more.Windows.Foundation.DateTime: ...
    @winrt_commethod(10)
    def put_Timestamp(self, value: win32more.Windows.Foundation.DateTime) -> Void: ...
    @winrt_commethod(11)
    def get_TargetUri(self) -> win32more.Windows.Foundation.Uri: ...
    @winrt_commethod(12)
    def put_TargetUri(self, value: win32more.Windows.Foundation.Uri) -> Void: ...
    @winrt_commethod(13)
    def put_Thumbnail(self, value: win32more.Windows.ApplicationModel.SocialInfo.SocialItemThumbnail) -> Void: ...
    @winrt_commethod(14)
    def get_Thumbnail(self) -> win32more.Windows.ApplicationModel.SocialInfo.SocialItemThumbnail: ...
    Content = property(get_Content, None)
    OriginalSource = property(get_OriginalSource, put_OriginalSource)
    TargetUri = property(get_TargetUri, put_TargetUri)
    Thumbnail = property(get_Thumbnail, put_Thumbnail)
    Timestamp = property(get_Timestamp, put_Timestamp)
class ISocialItemThumbnail(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.SocialInfo.ISocialItemThumbnail'
    _iid_ = Guid('{5cbf831a-3f08-497f-917f-57e09d84b141}')
    @winrt_commethod(6)
    def get_TargetUri(self) -> win32more.Windows.Foundation.Uri: ...
    @winrt_commethod(7)
    def put_TargetUri(self, value: win32more.Windows.Foundation.Uri) -> Void: ...
    @winrt_commethod(8)
    def get_ImageUri(self) -> win32more.Windows.Foundation.Uri: ...
    @winrt_commethod(9)
    def put_ImageUri(self, value: win32more.Windows.Foundation.Uri) -> Void: ...
    @winrt_commethod(10)
    def get_BitmapSize(self) -> win32more.Windows.Graphics.Imaging.BitmapSize: ...
    @winrt_commethod(11)
    def put_BitmapSize(self, value: win32more.Windows.Graphics.Imaging.BitmapSize) -> Void: ...
    @winrt_commethod(12)
    def SetImageAsync(self, image: win32more.Windows.Storage.Streams.IInputStream) -> win32more.Windows.Foundation.IAsyncAction: ...
    BitmapSize = property(get_BitmapSize, put_BitmapSize)
    ImageUri = property(get_ImageUri, put_ImageUri)
    TargetUri = property(get_TargetUri, put_TargetUri)
class ISocialUserInfo(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.SocialInfo.ISocialUserInfo'
    _iid_ = Guid('{9e5e1bd1-90d0-4e1d-9554-844d46607f61}')
    @winrt_commethod(6)
    def get_DisplayName(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def put_DisplayName(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(8)
    def get_UserName(self) -> WinRT_String: ...
    @winrt_commethod(9)
    def put_UserName(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(10)
    def get_RemoteId(self) -> WinRT_String: ...
    @winrt_commethod(11)
    def put_RemoteId(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(12)
    def get_TargetUri(self) -> win32more.Windows.Foundation.Uri: ...
    @winrt_commethod(13)
    def put_TargetUri(self, value: win32more.Windows.Foundation.Uri) -> Void: ...
    DisplayName = property(get_DisplayName, put_DisplayName)
    RemoteId = property(get_RemoteId, put_RemoteId)
    TargetUri = property(get_TargetUri, put_TargetUri)
    UserName = property(get_UserName, put_UserName)
class SocialFeedChildItem(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.ApplicationModel.SocialInfo.ISocialFeedChildItem
    _classid_ = 'Windows.ApplicationModel.SocialInfo.SocialFeedChildItem'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.ApplicationModel.SocialInfo.SocialFeedChildItem.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.ApplicationModel.SocialInfo.SocialFeedChildItem: ...
    @winrt_mixinmethod
    def get_Author(self: win32more.Windows.ApplicationModel.SocialInfo.ISocialFeedChildItem) -> win32more.Windows.ApplicationModel.SocialInfo.SocialUserInfo: ...
    @winrt_mixinmethod
    def get_PrimaryContent(self: win32more.Windows.ApplicationModel.SocialInfo.ISocialFeedChildItem) -> win32more.Windows.ApplicationModel.SocialInfo.SocialFeedContent: ...
    @winrt_mixinmethod
    def get_SecondaryContent(self: win32more.Windows.ApplicationModel.SocialInfo.ISocialFeedChildItem) -> win32more.Windows.ApplicationModel.SocialInfo.SocialFeedContent: ...
    @winrt_mixinmethod
    def get_Timestamp(self: win32more.Windows.ApplicationModel.SocialInfo.ISocialFeedChildItem) -> win32more.Windows.Foundation.DateTime: ...
    @winrt_mixinmethod
    def put_Timestamp(self: win32more.Windows.ApplicationModel.SocialInfo.ISocialFeedChildItem, value: win32more.Windows.Foundation.DateTime) -> Void: ...
    @winrt_mixinmethod
    def get_TargetUri(self: win32more.Windows.ApplicationModel.SocialInfo.ISocialFeedChildItem) -> win32more.Windows.Foundation.Uri: ...
    @winrt_mixinmethod
    def put_TargetUri(self: win32more.Windows.ApplicationModel.SocialInfo.ISocialFeedChildItem, value: win32more.Windows.Foundation.Uri) -> Void: ...
    @winrt_mixinmethod
    def get_Thumbnails(self: win32more.Windows.ApplicationModel.SocialInfo.ISocialFeedChildItem) -> win32more.Windows.Foundation.Collections.IVector[win32more.Windows.ApplicationModel.SocialInfo.SocialItemThumbnail]: ...
    @winrt_mixinmethod
    def get_SharedItem(self: win32more.Windows.ApplicationModel.SocialInfo.ISocialFeedChildItem) -> win32more.Windows.ApplicationModel.SocialInfo.SocialFeedSharedItem: ...
    @winrt_mixinmethod
    def put_SharedItem(self: win32more.Windows.ApplicationModel.SocialInfo.ISocialFeedChildItem, value: win32more.Windows.ApplicationModel.SocialInfo.SocialFeedSharedItem) -> Void: ...
    Author = property(get_Author, None)
    PrimaryContent = property(get_PrimaryContent, None)
    SecondaryContent = property(get_SecondaryContent, None)
    SharedItem = property(get_SharedItem, put_SharedItem)
    TargetUri = property(get_TargetUri, put_TargetUri)
    Thumbnails = property(get_Thumbnails, None)
    Timestamp = property(get_Timestamp, put_Timestamp)
class SocialFeedContent(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.ApplicationModel.SocialInfo.ISocialFeedContent
    _classid_ = 'Windows.ApplicationModel.SocialInfo.SocialFeedContent'
    @winrt_mixinmethod
    def get_Title(self: win32more.Windows.ApplicationModel.SocialInfo.ISocialFeedContent) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_Title(self: win32more.Windows.ApplicationModel.SocialInfo.ISocialFeedContent, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_Message(self: win32more.Windows.ApplicationModel.SocialInfo.ISocialFeedContent) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_Message(self: win32more.Windows.ApplicationModel.SocialInfo.ISocialFeedContent, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_TargetUri(self: win32more.Windows.ApplicationModel.SocialInfo.ISocialFeedContent) -> win32more.Windows.Foundation.Uri: ...
    @winrt_mixinmethod
    def put_TargetUri(self: win32more.Windows.ApplicationModel.SocialInfo.ISocialFeedContent, value: win32more.Windows.Foundation.Uri) -> Void: ...
    Message = property(get_Message, put_Message)
    TargetUri = property(get_TargetUri, put_TargetUri)
    Title = property(get_Title, put_Title)
class SocialFeedItem(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.ApplicationModel.SocialInfo.ISocialFeedItem
    _classid_ = 'Windows.ApplicationModel.SocialInfo.SocialFeedItem'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.ApplicationModel.SocialInfo.SocialFeedItem.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.ApplicationModel.SocialInfo.SocialFeedItem: ...
    @winrt_mixinmethod
    def get_Author(self: win32more.Windows.ApplicationModel.SocialInfo.ISocialFeedItem) -> win32more.Windows.ApplicationModel.SocialInfo.SocialUserInfo: ...
    @winrt_mixinmethod
    def get_PrimaryContent(self: win32more.Windows.ApplicationModel.SocialInfo.ISocialFeedItem) -> win32more.Windows.ApplicationModel.SocialInfo.SocialFeedContent: ...
    @winrt_mixinmethod
    def get_SecondaryContent(self: win32more.Windows.ApplicationModel.SocialInfo.ISocialFeedItem) -> win32more.Windows.ApplicationModel.SocialInfo.SocialFeedContent: ...
    @winrt_mixinmethod
    def get_Timestamp(self: win32more.Windows.ApplicationModel.SocialInfo.ISocialFeedItem) -> win32more.Windows.Foundation.DateTime: ...
    @winrt_mixinmethod
    def put_Timestamp(self: win32more.Windows.ApplicationModel.SocialInfo.ISocialFeedItem, value: win32more.Windows.Foundation.DateTime) -> Void: ...
    @winrt_mixinmethod
    def get_TargetUri(self: win32more.Windows.ApplicationModel.SocialInfo.ISocialFeedItem) -> win32more.Windows.Foundation.Uri: ...
    @winrt_mixinmethod
    def put_TargetUri(self: win32more.Windows.ApplicationModel.SocialInfo.ISocialFeedItem, value: win32more.Windows.Foundation.Uri) -> Void: ...
    @winrt_mixinmethod
    def get_Thumbnails(self: win32more.Windows.ApplicationModel.SocialInfo.ISocialFeedItem) -> win32more.Windows.Foundation.Collections.IVector[win32more.Windows.ApplicationModel.SocialInfo.SocialItemThumbnail]: ...
    @winrt_mixinmethod
    def get_SharedItem(self: win32more.Windows.ApplicationModel.SocialInfo.ISocialFeedItem) -> win32more.Windows.ApplicationModel.SocialInfo.SocialFeedSharedItem: ...
    @winrt_mixinmethod
    def put_SharedItem(self: win32more.Windows.ApplicationModel.SocialInfo.ISocialFeedItem, value: win32more.Windows.ApplicationModel.SocialInfo.SocialFeedSharedItem) -> Void: ...
    @winrt_mixinmethod
    def get_BadgeStyle(self: win32more.Windows.ApplicationModel.SocialInfo.ISocialFeedItem) -> win32more.Windows.ApplicationModel.SocialInfo.SocialItemBadgeStyle: ...
    @winrt_mixinmethod
    def put_BadgeStyle(self: win32more.Windows.ApplicationModel.SocialInfo.ISocialFeedItem, value: win32more.Windows.ApplicationModel.SocialInfo.SocialItemBadgeStyle) -> Void: ...
    @winrt_mixinmethod
    def get_BadgeCountValue(self: win32more.Windows.ApplicationModel.SocialInfo.ISocialFeedItem) -> Int32: ...
    @winrt_mixinmethod
    def put_BadgeCountValue(self: win32more.Windows.ApplicationModel.SocialInfo.ISocialFeedItem, value: Int32) -> Void: ...
    @winrt_mixinmethod
    def get_RemoteId(self: win32more.Windows.ApplicationModel.SocialInfo.ISocialFeedItem) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_RemoteId(self: win32more.Windows.ApplicationModel.SocialInfo.ISocialFeedItem, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_ChildItem(self: win32more.Windows.ApplicationModel.SocialInfo.ISocialFeedItem) -> win32more.Windows.ApplicationModel.SocialInfo.SocialFeedChildItem: ...
    @winrt_mixinmethod
    def put_ChildItem(self: win32more.Windows.ApplicationModel.SocialInfo.ISocialFeedItem, value: win32more.Windows.ApplicationModel.SocialInfo.SocialFeedChildItem) -> Void: ...
    @winrt_mixinmethod
    def get_Style(self: win32more.Windows.ApplicationModel.SocialInfo.ISocialFeedItem) -> win32more.Windows.ApplicationModel.SocialInfo.SocialFeedItemStyle: ...
    @winrt_mixinmethod
    def put_Style(self: win32more.Windows.ApplicationModel.SocialInfo.ISocialFeedItem, value: win32more.Windows.ApplicationModel.SocialInfo.SocialFeedItemStyle) -> Void: ...
    Author = property(get_Author, None)
    BadgeCountValue = property(get_BadgeCountValue, put_BadgeCountValue)
    BadgeStyle = property(get_BadgeStyle, put_BadgeStyle)
    ChildItem = property(get_ChildItem, put_ChildItem)
    PrimaryContent = property(get_PrimaryContent, None)
    RemoteId = property(get_RemoteId, put_RemoteId)
    SecondaryContent = property(get_SecondaryContent, None)
    SharedItem = property(get_SharedItem, put_SharedItem)
    Style = property(get_Style, put_Style)
    TargetUri = property(get_TargetUri, put_TargetUri)
    Thumbnails = property(get_Thumbnails, None)
    Timestamp = property(get_Timestamp, put_Timestamp)
class SocialFeedItemStyle(Enum, Int32):
    Default = 0
    Photo = 1
class SocialFeedKind(Enum, Int32):
    HomeFeed = 0
    ContactFeed = 1
    Dashboard = 2
class SocialFeedSharedItem(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.ApplicationModel.SocialInfo.ISocialFeedSharedItem
    _classid_ = 'Windows.ApplicationModel.SocialInfo.SocialFeedSharedItem'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.ApplicationModel.SocialInfo.SocialFeedSharedItem.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.ApplicationModel.SocialInfo.SocialFeedSharedItem: ...
    @winrt_mixinmethod
    def get_OriginalSource(self: win32more.Windows.ApplicationModel.SocialInfo.ISocialFeedSharedItem) -> win32more.Windows.Foundation.Uri: ...
    @winrt_mixinmethod
    def put_OriginalSource(self: win32more.Windows.ApplicationModel.SocialInfo.ISocialFeedSharedItem, value: win32more.Windows.Foundation.Uri) -> Void: ...
    @winrt_mixinmethod
    def get_Content(self: win32more.Windows.ApplicationModel.SocialInfo.ISocialFeedSharedItem) -> win32more.Windows.ApplicationModel.SocialInfo.SocialFeedContent: ...
    @winrt_mixinmethod
    def get_Timestamp(self: win32more.Windows.ApplicationModel.SocialInfo.ISocialFeedSharedItem) -> win32more.Windows.Foundation.DateTime: ...
    @winrt_mixinmethod
    def put_Timestamp(self: win32more.Windows.ApplicationModel.SocialInfo.ISocialFeedSharedItem, value: win32more.Windows.Foundation.DateTime) -> Void: ...
    @winrt_mixinmethod
    def get_TargetUri(self: win32more.Windows.ApplicationModel.SocialInfo.ISocialFeedSharedItem) -> win32more.Windows.Foundation.Uri: ...
    @winrt_mixinmethod
    def put_TargetUri(self: win32more.Windows.ApplicationModel.SocialInfo.ISocialFeedSharedItem, value: win32more.Windows.Foundation.Uri) -> Void: ...
    @winrt_mixinmethod
    def put_Thumbnail(self: win32more.Windows.ApplicationModel.SocialInfo.ISocialFeedSharedItem, value: win32more.Windows.ApplicationModel.SocialInfo.SocialItemThumbnail) -> Void: ...
    @winrt_mixinmethod
    def get_Thumbnail(self: win32more.Windows.ApplicationModel.SocialInfo.ISocialFeedSharedItem) -> win32more.Windows.ApplicationModel.SocialInfo.SocialItemThumbnail: ...
    Content = property(get_Content, None)
    OriginalSource = property(get_OriginalSource, put_OriginalSource)
    TargetUri = property(get_TargetUri, put_TargetUri)
    Thumbnail = property(get_Thumbnail, put_Thumbnail)
    Timestamp = property(get_Timestamp, put_Timestamp)
class SocialFeedUpdateMode(Enum, Int32):
    Append = 0
    Replace = 1
SocialInfoContract: UInt32 = 131072
class SocialItemBadgeStyle(Enum, Int32):
    Hidden = 0
    Visible = 1
    VisibleWithCount = 2
class SocialItemThumbnail(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.ApplicationModel.SocialInfo.ISocialItemThumbnail
    _classid_ = 'Windows.ApplicationModel.SocialInfo.SocialItemThumbnail'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.ApplicationModel.SocialInfo.SocialItemThumbnail.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.ApplicationModel.SocialInfo.SocialItemThumbnail: ...
    @winrt_mixinmethod
    def get_TargetUri(self: win32more.Windows.ApplicationModel.SocialInfo.ISocialItemThumbnail) -> win32more.Windows.Foundation.Uri: ...
    @winrt_mixinmethod
    def put_TargetUri(self: win32more.Windows.ApplicationModel.SocialInfo.ISocialItemThumbnail, value: win32more.Windows.Foundation.Uri) -> Void: ...
    @winrt_mixinmethod
    def get_ImageUri(self: win32more.Windows.ApplicationModel.SocialInfo.ISocialItemThumbnail) -> win32more.Windows.Foundation.Uri: ...
    @winrt_mixinmethod
    def put_ImageUri(self: win32more.Windows.ApplicationModel.SocialInfo.ISocialItemThumbnail, value: win32more.Windows.Foundation.Uri) -> Void: ...
    @winrt_mixinmethod
    def get_BitmapSize(self: win32more.Windows.ApplicationModel.SocialInfo.ISocialItemThumbnail) -> win32more.Windows.Graphics.Imaging.BitmapSize: ...
    @winrt_mixinmethod
    def put_BitmapSize(self: win32more.Windows.ApplicationModel.SocialInfo.ISocialItemThumbnail, value: win32more.Windows.Graphics.Imaging.BitmapSize) -> Void: ...
    @winrt_mixinmethod
    def SetImageAsync(self: win32more.Windows.ApplicationModel.SocialInfo.ISocialItemThumbnail, image: win32more.Windows.Storage.Streams.IInputStream) -> win32more.Windows.Foundation.IAsyncAction: ...
    BitmapSize = property(get_BitmapSize, put_BitmapSize)
    ImageUri = property(get_ImageUri, put_ImageUri)
    TargetUri = property(get_TargetUri, put_TargetUri)
class SocialUserInfo(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.ApplicationModel.SocialInfo.ISocialUserInfo
    _classid_ = 'Windows.ApplicationModel.SocialInfo.SocialUserInfo'
    @winrt_mixinmethod
    def get_DisplayName(self: win32more.Windows.ApplicationModel.SocialInfo.ISocialUserInfo) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_DisplayName(self: win32more.Windows.ApplicationModel.SocialInfo.ISocialUserInfo, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_UserName(self: win32more.Windows.ApplicationModel.SocialInfo.ISocialUserInfo) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_UserName(self: win32more.Windows.ApplicationModel.SocialInfo.ISocialUserInfo, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_RemoteId(self: win32more.Windows.ApplicationModel.SocialInfo.ISocialUserInfo) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_RemoteId(self: win32more.Windows.ApplicationModel.SocialInfo.ISocialUserInfo, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_TargetUri(self: win32more.Windows.ApplicationModel.SocialInfo.ISocialUserInfo) -> win32more.Windows.Foundation.Uri: ...
    @winrt_mixinmethod
    def put_TargetUri(self: win32more.Windows.ApplicationModel.SocialInfo.ISocialUserInfo, value: win32more.Windows.Foundation.Uri) -> Void: ...
    DisplayName = property(get_DisplayName, put_DisplayName)
    RemoteId = property(get_RemoteId, put_RemoteId)
    TargetUri = property(get_TargetUri, put_TargetUri)
    UserName = property(get_UserName, put_UserName)


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.Foundation
import win32more.Windows.Win32.Graphics.Gdi
import win32more.Windows.Win32.Security
import win32more.Windows.Win32.System.DataExchange
WM_DDE_FIRST: UInt32 = 992
WM_DDE_INITIATE: UInt32 = 992
WM_DDE_TERMINATE: UInt32 = 993
WM_DDE_ADVISE: UInt32 = 994
WM_DDE_UNADVISE: UInt32 = 995
WM_DDE_ACK: UInt32 = 996
WM_DDE_DATA: UInt32 = 997
WM_DDE_REQUEST: UInt32 = 998
WM_DDE_POKE: UInt32 = 999
WM_DDE_EXECUTE: UInt32 = 1000
WM_DDE_LAST: UInt32 = 1000
CADV_LATEACK: UInt32 = 65535
DDE_FACK: UInt32 = 32768
DDE_FBUSY: UInt32 = 16384
DDE_FDEFERUPD: UInt32 = 16384
DDE_FACKREQ: UInt32 = 32768
DDE_FRELEASE: UInt32 = 8192
DDE_FREQUESTED: UInt32 = 4096
DDE_FAPPSTATUS: UInt32 = 255
DDE_FNOTPROCESSED: UInt32 = 0
MSGF_DDEMGR: UInt32 = 32769
CP_WINANSI: Int32 = 1004
CP_WINUNICODE: Int32 = 1200
CP_WINNEUTRAL: Int32 = 1200
XTYPF_NOBLOCK: UInt32 = 2
XTYPF_NODATA: UInt32 = 4
XTYPF_ACKREQ: UInt32 = 8
XCLASS_MASK: UInt32 = 64512
XCLASS_BOOL: UInt32 = 4096
XCLASS_DATA: UInt32 = 8192
XCLASS_FLAGS: UInt32 = 16384
XCLASS_NOTIFICATION: UInt32 = 32768
XTYP_MASK: UInt32 = 240
XTYP_SHIFT: UInt32 = 4
TIMEOUT_ASYNC: UInt32 = 4294967295
QID_SYNC: UInt32 = 4294967295
SZDDESYS_TOPIC: String = 'System'
SZDDESYS_ITEM_TOPICS: String = 'Topics'
SZDDESYS_ITEM_SYSITEMS: String = 'SysItems'
SZDDESYS_ITEM_RTNMSG: String = 'ReturnMessage'
SZDDESYS_ITEM_STATUS: String = 'Status'
SZDDESYS_ITEM_FORMATS: String = 'Formats'
SZDDESYS_ITEM_HELP: String = 'Help'
SZDDE_ITEM_ITEMLIST: String = 'TopicItemList'
APPCMD_MASK: Int32 = 4080
APPCLASS_MASK: Int32 = 15
HDATA_APPOWNED: UInt32 = 1
DMLERR_NO_ERROR: UInt32 = 0
DMLERR_FIRST: UInt32 = 16384
DMLERR_ADVACKTIMEOUT: UInt32 = 16384
DMLERR_BUSY: UInt32 = 16385
DMLERR_DATAACKTIMEOUT: UInt32 = 16386
DMLERR_DLL_NOT_INITIALIZED: UInt32 = 16387
DMLERR_DLL_USAGE: UInt32 = 16388
DMLERR_EXECACKTIMEOUT: UInt32 = 16389
DMLERR_INVALIDPARAMETER: UInt32 = 16390
DMLERR_LOW_MEMORY: UInt32 = 16391
DMLERR_MEMORY_ERROR: UInt32 = 16392
DMLERR_NOTPROCESSED: UInt32 = 16393
DMLERR_NO_CONV_ESTABLISHED: UInt32 = 16394
DMLERR_POKEACKTIMEOUT: UInt32 = 16395
DMLERR_POSTMSG_FAILED: UInt32 = 16396
DMLERR_REENTRANCY: UInt32 = 16397
DMLERR_SERVER_DIED: UInt32 = 16398
DMLERR_SYS_ERROR: UInt32 = 16399
DMLERR_UNADVACKTIMEOUT: UInt32 = 16400
DMLERR_UNFOUND_QUEUE_ID: UInt32 = 16401
DMLERR_LAST: UInt32 = 16401
MH_CREATE: UInt32 = 1
MH_KEEP: UInt32 = 2
MH_DELETE: UInt32 = 3
MH_CLEANUP: UInt32 = 4
MAX_MONITORS: UInt32 = 4
MF_MASK: UInt32 = 4278190080
@winfunctype('USER32.dll')
def DdeSetQualityOfService(hwndClient: win32more.Windows.Win32.Foundation.HWND, pqosNew: POINTER(win32more.Windows.Win32.Security.SECURITY_QUALITY_OF_SERVICE), pqosPrev: POINTER(win32more.Windows.Win32.Security.SECURITY_QUALITY_OF_SERVICE)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def ImpersonateDdeClientWindow(hWndClient: win32more.Windows.Win32.Foundation.HWND, hWndServer: win32more.Windows.Win32.Foundation.HWND) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def PackDDElParam(msg: UInt32, uiLo: UIntPtr, uiHi: UIntPtr) -> win32more.Windows.Win32.Foundation.LPARAM: ...
@winfunctype('USER32.dll')
def UnpackDDElParam(msg: UInt32, lParam: win32more.Windows.Win32.Foundation.LPARAM, puiLo: POINTER(UIntPtr), puiHi: POINTER(UIntPtr)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def FreeDDElParam(msg: UInt32, lParam: win32more.Windows.Win32.Foundation.LPARAM) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def ReuseDDElParam(lParam: win32more.Windows.Win32.Foundation.LPARAM, msgIn: UInt32, msgOut: UInt32, uiLo: UIntPtr, uiHi: UIntPtr) -> win32more.Windows.Win32.Foundation.LPARAM: ...
@winfunctype('USER32.dll')
def DdeInitializeA(pidInst: POINTER(UInt32), pfnCallback: win32more.Windows.Win32.System.DataExchange.PFNCALLBACK, afCmd: win32more.Windows.Win32.System.DataExchange.DDE_INITIALIZE_COMMAND, ulRes: UInt32) -> UInt32: ...
@winfunctype('USER32.dll')
def DdeInitializeW(pidInst: POINTER(UInt32), pfnCallback: win32more.Windows.Win32.System.DataExchange.PFNCALLBACK, afCmd: win32more.Windows.Win32.System.DataExchange.DDE_INITIALIZE_COMMAND, ulRes: UInt32) -> UInt32: ...
DdeInitialize = UnicodeAlias('DdeInitializeW')
@winfunctype('USER32.dll')
def DdeUninitialize(idInst: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def DdeConnectList(idInst: UInt32, hszService: win32more.Windows.Win32.System.DataExchange.HSZ, hszTopic: win32more.Windows.Win32.System.DataExchange.HSZ, hConvList: win32more.Windows.Win32.System.DataExchange.HCONVLIST, pCC: POINTER(win32more.Windows.Win32.System.DataExchange.CONVCONTEXT)) -> win32more.Windows.Win32.System.DataExchange.HCONVLIST: ...
@winfunctype('USER32.dll')
def DdeQueryNextServer(hConvList: win32more.Windows.Win32.System.DataExchange.HCONVLIST, hConvPrev: win32more.Windows.Win32.System.DataExchange.HCONV) -> win32more.Windows.Win32.System.DataExchange.HCONV: ...
@winfunctype('USER32.dll')
def DdeDisconnectList(hConvList: win32more.Windows.Win32.System.DataExchange.HCONVLIST) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def DdeConnect(idInst: UInt32, hszService: win32more.Windows.Win32.System.DataExchange.HSZ, hszTopic: win32more.Windows.Win32.System.DataExchange.HSZ, pCC: POINTER(win32more.Windows.Win32.System.DataExchange.CONVCONTEXT)) -> win32more.Windows.Win32.System.DataExchange.HCONV: ...
@winfunctype('USER32.dll')
def DdeDisconnect(hConv: win32more.Windows.Win32.System.DataExchange.HCONV) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def DdeReconnect(hConv: win32more.Windows.Win32.System.DataExchange.HCONV) -> win32more.Windows.Win32.System.DataExchange.HCONV: ...
@winfunctype('USER32.dll')
def DdeQueryConvInfo(hConv: win32more.Windows.Win32.System.DataExchange.HCONV, idTransaction: UInt32, pConvInfo: POINTER(win32more.Windows.Win32.System.DataExchange.CONVINFO)) -> UInt32: ...
@winfunctype('USER32.dll')
def DdeSetUserHandle(hConv: win32more.Windows.Win32.System.DataExchange.HCONV, id: UInt32, hUser: UIntPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def DdeAbandonTransaction(idInst: UInt32, hConv: win32more.Windows.Win32.System.DataExchange.HCONV, idTransaction: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def DdePostAdvise(idInst: UInt32, hszTopic: win32more.Windows.Win32.System.DataExchange.HSZ, hszItem: win32more.Windows.Win32.System.DataExchange.HSZ) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def DdeEnableCallback(idInst: UInt32, hConv: win32more.Windows.Win32.System.DataExchange.HCONV, wCmd: win32more.Windows.Win32.System.DataExchange.DDE_ENABLE_CALLBACK_CMD) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def DdeImpersonateClient(hConv: win32more.Windows.Win32.System.DataExchange.HCONV) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def DdeNameService(idInst: UInt32, hsz1: win32more.Windows.Win32.System.DataExchange.HSZ, hsz2: win32more.Windows.Win32.System.DataExchange.HSZ, afCmd: win32more.Windows.Win32.System.DataExchange.DDE_NAME_SERVICE_CMD) -> win32more.Windows.Win32.System.DataExchange.HDDEDATA: ...
@winfunctype('USER32.dll')
def DdeClientTransaction(pData: POINTER(Byte), cbData: UInt32, hConv: win32more.Windows.Win32.System.DataExchange.HCONV, hszItem: win32more.Windows.Win32.System.DataExchange.HSZ, wFmt: UInt32, wType: win32more.Windows.Win32.System.DataExchange.DDE_CLIENT_TRANSACTION_TYPE, dwTimeout: UInt32, pdwResult: POINTER(UInt32)) -> win32more.Windows.Win32.System.DataExchange.HDDEDATA: ...
@winfunctype('USER32.dll')
def DdeCreateDataHandle(idInst: UInt32, pSrc: POINTER(Byte), cb: UInt32, cbOff: UInt32, hszItem: win32more.Windows.Win32.System.DataExchange.HSZ, wFmt: UInt32, afCmd: UInt32) -> win32more.Windows.Win32.System.DataExchange.HDDEDATA: ...
@winfunctype('USER32.dll')
def DdeAddData(hData: win32more.Windows.Win32.System.DataExchange.HDDEDATA, pSrc: POINTER(Byte), cb: UInt32, cbOff: UInt32) -> win32more.Windows.Win32.System.DataExchange.HDDEDATA: ...
@winfunctype('USER32.dll')
def DdeGetData(hData: win32more.Windows.Win32.System.DataExchange.HDDEDATA, pDst: POINTER(Byte), cbMax: UInt32, cbOff: UInt32) -> UInt32: ...
@winfunctype('USER32.dll')
def DdeAccessData(hData: win32more.Windows.Win32.System.DataExchange.HDDEDATA, pcbDataSize: POINTER(UInt32)) -> POINTER(Byte): ...
@winfunctype('USER32.dll')
def DdeUnaccessData(hData: win32more.Windows.Win32.System.DataExchange.HDDEDATA) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def DdeFreeDataHandle(hData: win32more.Windows.Win32.System.DataExchange.HDDEDATA) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def DdeGetLastError(idInst: UInt32) -> UInt32: ...
@winfunctype('USER32.dll')
def DdeCreateStringHandleA(idInst: UInt32, psz: win32more.Windows.Win32.Foundation.PSTR, iCodePage: Int32) -> win32more.Windows.Win32.System.DataExchange.HSZ: ...
@winfunctype('USER32.dll')
def DdeCreateStringHandleW(idInst: UInt32, psz: win32more.Windows.Win32.Foundation.PWSTR, iCodePage: Int32) -> win32more.Windows.Win32.System.DataExchange.HSZ: ...
DdeCreateStringHandle = UnicodeAlias('DdeCreateStringHandleW')
@winfunctype('USER32.dll')
def DdeQueryStringA(idInst: UInt32, hsz: win32more.Windows.Win32.System.DataExchange.HSZ, psz: win32more.Windows.Win32.Foundation.PSTR, cchMax: UInt32, iCodePage: Int32) -> UInt32: ...
@winfunctype('USER32.dll')
def DdeQueryStringW(idInst: UInt32, hsz: win32more.Windows.Win32.System.DataExchange.HSZ, psz: win32more.Windows.Win32.Foundation.PWSTR, cchMax: UInt32, iCodePage: Int32) -> UInt32: ...
DdeQueryString = UnicodeAlias('DdeQueryStringW')
@winfunctype('USER32.dll')
def DdeFreeStringHandle(idInst: UInt32, hsz: win32more.Windows.Win32.System.DataExchange.HSZ) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def DdeKeepStringHandle(idInst: UInt32, hsz: win32more.Windows.Win32.System.DataExchange.HSZ) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def DdeCmpStringHandles(hsz1: win32more.Windows.Win32.System.DataExchange.HSZ, hsz2: win32more.Windows.Win32.System.DataExchange.HSZ) -> Int32: ...
@winfunctype('GDI32.dll')
def SetWinMetaFileBits(nSize: UInt32, lpMeta16Data: POINTER(Byte), hdcRef: win32more.Windows.Win32.Graphics.Gdi.HDC, lpMFP: POINTER(win32more.Windows.Win32.System.DataExchange.METAFILEPICT)) -> win32more.Windows.Win32.Graphics.Gdi.HENHMETAFILE: ...
@winfunctype('USER32.dll')
def OpenClipboard(hWndNewOwner: win32more.Windows.Win32.Foundation.HWND) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def CloseClipboard() -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def GetClipboardSequenceNumber() -> UInt32: ...
@winfunctype('USER32.dll')
def GetClipboardOwner() -> win32more.Windows.Win32.Foundation.HWND: ...
@winfunctype('USER32.dll')
def SetClipboardViewer(hWndNewViewer: win32more.Windows.Win32.Foundation.HWND) -> win32more.Windows.Win32.Foundation.HWND: ...
@winfunctype('USER32.dll')
def GetClipboardViewer() -> win32more.Windows.Win32.Foundation.HWND: ...
@winfunctype('USER32.dll')
def ChangeClipboardChain(hWndRemove: win32more.Windows.Win32.Foundation.HWND, hWndNewNext: win32more.Windows.Win32.Foundation.HWND) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def SetClipboardData(uFormat: UInt32, hMem: win32more.Windows.Win32.Foundation.HANDLE) -> win32more.Windows.Win32.Foundation.HANDLE: ...
@winfunctype('USER32.dll')
def GetClipboardData(uFormat: UInt32) -> win32more.Windows.Win32.Foundation.HANDLE: ...
@winfunctype('USER32.dll')
def RegisterClipboardFormatA(lpszFormat: win32more.Windows.Win32.Foundation.PSTR) -> UInt32: ...
@winfunctype('USER32.dll')
def RegisterClipboardFormatW(lpszFormat: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
RegisterClipboardFormat = UnicodeAlias('RegisterClipboardFormatW')
@winfunctype('USER32.dll')
def CountClipboardFormats() -> Int32: ...
@winfunctype('USER32.dll')
def EnumClipboardFormats(format: UInt32) -> UInt32: ...
@winfunctype('USER32.dll')
def GetClipboardFormatNameA(format: UInt32, lpszFormatName: win32more.Windows.Win32.Foundation.PSTR, cchMaxCount: Int32) -> Int32: ...
@winfunctype('USER32.dll')
def GetClipboardFormatNameW(format: UInt32, lpszFormatName: win32more.Windows.Win32.Foundation.PWSTR, cchMaxCount: Int32) -> Int32: ...
GetClipboardFormatName = UnicodeAlias('GetClipboardFormatNameW')
@winfunctype('USER32.dll')
def EmptyClipboard() -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def IsClipboardFormatAvailable(format: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def GetPriorityClipboardFormat(paFormatPriorityList: POINTER(UInt32), cFormats: Int32) -> Int32: ...
@winfunctype('USER32.dll')
def GetOpenClipboardWindow() -> win32more.Windows.Win32.Foundation.HWND: ...
@winfunctype('USER32.dll')
def AddClipboardFormatListener(hwnd: win32more.Windows.Win32.Foundation.HWND) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def RemoveClipboardFormatListener(hwnd: win32more.Windows.Win32.Foundation.HWND) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def GetUpdatedClipboardFormats(lpuiFormats: POINTER(UInt32), cFormats: UInt32, pcFormatsOut: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def GlobalDeleteAtom(nAtom: UInt16) -> UInt16: ...
@winfunctype('KERNEL32.dll')
def InitAtomTable(nSize: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def DeleteAtom(nAtom: UInt16) -> UInt16: ...
@winfunctype('KERNEL32.dll')
def GlobalAddAtomA(lpString: win32more.Windows.Win32.Foundation.PSTR) -> UInt16: ...
@winfunctype('KERNEL32.dll')
def GlobalAddAtomW(lpString: win32more.Windows.Win32.Foundation.PWSTR) -> UInt16: ...
GlobalAddAtom = UnicodeAlias('GlobalAddAtomW')
@winfunctype('KERNEL32.dll')
def GlobalAddAtomExA(lpString: win32more.Windows.Win32.Foundation.PSTR, Flags: UInt32) -> UInt16: ...
@winfunctype('KERNEL32.dll')
def GlobalAddAtomExW(lpString: win32more.Windows.Win32.Foundation.PWSTR, Flags: UInt32) -> UInt16: ...
GlobalAddAtomEx = UnicodeAlias('GlobalAddAtomExW')
@winfunctype('KERNEL32.dll')
def GlobalFindAtomA(lpString: win32more.Windows.Win32.Foundation.PSTR) -> UInt16: ...
@winfunctype('KERNEL32.dll')
def GlobalFindAtomW(lpString: win32more.Windows.Win32.Foundation.PWSTR) -> UInt16: ...
GlobalFindAtom = UnicodeAlias('GlobalFindAtomW')
@winfunctype('KERNEL32.dll')
def GlobalGetAtomNameA(nAtom: UInt16, lpBuffer: win32more.Windows.Win32.Foundation.PSTR, nSize: Int32) -> UInt32: ...
@winfunctype('KERNEL32.dll')
def GlobalGetAtomNameW(nAtom: UInt16, lpBuffer: win32more.Windows.Win32.Foundation.PWSTR, nSize: Int32) -> UInt32: ...
GlobalGetAtomName = UnicodeAlias('GlobalGetAtomNameW')
@winfunctype('KERNEL32.dll')
def AddAtomA(lpString: win32more.Windows.Win32.Foundation.PSTR) -> UInt16: ...
@winfunctype('KERNEL32.dll')
def AddAtomW(lpString: win32more.Windows.Win32.Foundation.PWSTR) -> UInt16: ...
AddAtom = UnicodeAlias('AddAtomW')
@winfunctype('KERNEL32.dll')
def FindAtomA(lpString: win32more.Windows.Win32.Foundation.PSTR) -> UInt16: ...
@winfunctype('KERNEL32.dll')
def FindAtomW(lpString: win32more.Windows.Win32.Foundation.PWSTR) -> UInt16: ...
FindAtom = UnicodeAlias('FindAtomW')
@winfunctype('KERNEL32.dll')
def GetAtomNameA(nAtom: UInt16, lpBuffer: win32more.Windows.Win32.Foundation.PSTR, nSize: Int32) -> UInt32: ...
@winfunctype('KERNEL32.dll')
def GetAtomNameW(nAtom: UInt16, lpBuffer: win32more.Windows.Win32.Foundation.PWSTR, nSize: Int32) -> UInt32: ...
GetAtomName = UnicodeAlias('GetAtomNameW')
class CONVCONTEXT(Structure):
    cb: UInt32
    wFlags: UInt32
    wCountryID: UInt32
    iCodePage: Int32
    dwLangID: UInt32
    dwSecurity: UInt32
    qos: win32more.Windows.Win32.Security.SECURITY_QUALITY_OF_SERVICE
class CONVINFO(Structure):
    cb: UInt32
    hUser: UIntPtr
    hConvPartner: win32more.Windows.Win32.System.DataExchange.HCONV
    hszSvcPartner: win32more.Windows.Win32.System.DataExchange.HSZ
    hszServiceReq: win32more.Windows.Win32.System.DataExchange.HSZ
    hszTopic: win32more.Windows.Win32.System.DataExchange.HSZ
    hszItem: win32more.Windows.Win32.System.DataExchange.HSZ
    wFmt: UInt32
    wType: win32more.Windows.Win32.System.DataExchange.DDE_CLIENT_TRANSACTION_TYPE
    wStatus: win32more.Windows.Win32.System.DataExchange.CONVINFO_STATUS
    wConvst: win32more.Windows.Win32.System.DataExchange.CONVINFO_CONVERSATION_STATE
    wLastError: UInt32
    hConvList: win32more.Windows.Win32.System.DataExchange.HCONVLIST
    ConvCtxt: win32more.Windows.Win32.System.DataExchange.CONVCONTEXT
    hwnd: win32more.Windows.Win32.Foundation.HWND
    hwndPartner: win32more.Windows.Win32.Foundation.HWND
CONVINFO_CONVERSATION_STATE = UInt32
XST_ADVACKRCVD: win32more.Windows.Win32.System.DataExchange.CONVINFO_CONVERSATION_STATE = 13
XST_ADVDATAACKRCVD: win32more.Windows.Win32.System.DataExchange.CONVINFO_CONVERSATION_STATE = 16
XST_ADVDATASENT: win32more.Windows.Win32.System.DataExchange.CONVINFO_CONVERSATION_STATE = 15
XST_ADVSENT: win32more.Windows.Win32.System.DataExchange.CONVINFO_CONVERSATION_STATE = 11
XST_CONNECTED: win32more.Windows.Win32.System.DataExchange.CONVINFO_CONVERSATION_STATE = 2
XST_DATARCVD: win32more.Windows.Win32.System.DataExchange.CONVINFO_CONVERSATION_STATE = 6
XST_EXECACKRCVD: win32more.Windows.Win32.System.DataExchange.CONVINFO_CONVERSATION_STATE = 10
XST_EXECSENT: win32more.Windows.Win32.System.DataExchange.CONVINFO_CONVERSATION_STATE = 9
XST_INCOMPLETE: win32more.Windows.Win32.System.DataExchange.CONVINFO_CONVERSATION_STATE = 1
XST_INIT1: win32more.Windows.Win32.System.DataExchange.CONVINFO_CONVERSATION_STATE = 3
XST_INIT2: win32more.Windows.Win32.System.DataExchange.CONVINFO_CONVERSATION_STATE = 4
XST_NULL: win32more.Windows.Win32.System.DataExchange.CONVINFO_CONVERSATION_STATE = 0
XST_POKEACKRCVD: win32more.Windows.Win32.System.DataExchange.CONVINFO_CONVERSATION_STATE = 8
XST_POKESENT: win32more.Windows.Win32.System.DataExchange.CONVINFO_CONVERSATION_STATE = 7
XST_REQSENT: win32more.Windows.Win32.System.DataExchange.CONVINFO_CONVERSATION_STATE = 5
XST_UNADVACKRCVD: win32more.Windows.Win32.System.DataExchange.CONVINFO_CONVERSATION_STATE = 14
XST_UNADVSENT: win32more.Windows.Win32.System.DataExchange.CONVINFO_CONVERSATION_STATE = 12
CONVINFO_STATUS = UInt32
ST_ADVISE: win32more.Windows.Win32.System.DataExchange.CONVINFO_STATUS = 2
ST_BLOCKED: win32more.Windows.Win32.System.DataExchange.CONVINFO_STATUS = 8
ST_BLOCKNEXT: win32more.Windows.Win32.System.DataExchange.CONVINFO_STATUS = 128
ST_CLIENT: win32more.Windows.Win32.System.DataExchange.CONVINFO_STATUS = 16
ST_CONNECTED: win32more.Windows.Win32.System.DataExchange.CONVINFO_STATUS = 1
ST_INLIST: win32more.Windows.Win32.System.DataExchange.CONVINFO_STATUS = 64
ST_ISLOCAL: win32more.Windows.Win32.System.DataExchange.CONVINFO_STATUS = 4
ST_ISSELF: win32more.Windows.Win32.System.DataExchange.CONVINFO_STATUS = 256
ST_TERMINATED: win32more.Windows.Win32.System.DataExchange.CONVINFO_STATUS = 32
class COPYDATASTRUCT(Structure):
    dwData: UIntPtr
    cbData: UInt32
    lpData: VoidPtr
class DDEACK(Structure):
    bAppReturnCode: Annotated[UInt16, 8]
    reserved: Annotated[UInt16, 6]
    fBusy: Annotated[UInt16, 1]
    fAck: Annotated[UInt16, 1]
class DDEADVISE(Structure):
    reserved: Annotated[UInt16, 14]
    fDeferUpd: Annotated[UInt16, 1]
    fAckReq: Annotated[UInt16, 1]
    cfFormat: Int16
class DDEDATA(Structure):
    unused: Annotated[UInt16, 12]
    fResponse: Annotated[UInt16, 1]
    fRelease: Annotated[UInt16, 1]
    reserved: Annotated[UInt16, 1]
    fAckReq: Annotated[UInt16, 1]
    cfFormat: Int16
    Value: Byte * 1
class DDELN(Structure):
    unused: Annotated[UInt16, 13]
    fRelease: Annotated[UInt16, 1]
    fDeferUpd: Annotated[UInt16, 1]
    fAckReq: Annotated[UInt16, 1]
    cfFormat: Int16
class DDEML_MSG_HOOK_DATA(Structure):
    uiLo: UIntPtr
    uiHi: UIntPtr
    cbData: UInt32
    Data: UInt32 * 8
class DDEPOKE(Structure):
    unused: Annotated[UInt16, 13]
    fRelease: Annotated[UInt16, 1]
    fReserved: Annotated[UInt16, 2]
    cfFormat: Int16
    Value: Byte * 1
class DDEUP(Structure):
    unused: Annotated[UInt16, 12]
    fAck: Annotated[UInt16, 1]
    fRelease: Annotated[UInt16, 1]
    fReserved: Annotated[UInt16, 1]
    fAckReq: Annotated[UInt16, 1]
    cfFormat: Int16
    rgb: Byte * 1
DDE_CLIENT_TRANSACTION_TYPE = UInt32
XTYP_ADVSTART: win32more.Windows.Win32.System.DataExchange.DDE_CLIENT_TRANSACTION_TYPE = 4144
XTYP_ADVSTOP: win32more.Windows.Win32.System.DataExchange.DDE_CLIENT_TRANSACTION_TYPE = 32832
XTYP_EXECUTE: win32more.Windows.Win32.System.DataExchange.DDE_CLIENT_TRANSACTION_TYPE = 16464
XTYP_POKE: win32more.Windows.Win32.System.DataExchange.DDE_CLIENT_TRANSACTION_TYPE = 16528
XTYP_REQUEST: win32more.Windows.Win32.System.DataExchange.DDE_CLIENT_TRANSACTION_TYPE = 8368
XTYP_ADVDATA: win32more.Windows.Win32.System.DataExchange.DDE_CLIENT_TRANSACTION_TYPE = 16400
XTYP_ADVREQ: win32more.Windows.Win32.System.DataExchange.DDE_CLIENT_TRANSACTION_TYPE = 8226
XTYP_CONNECT: win32more.Windows.Win32.System.DataExchange.DDE_CLIENT_TRANSACTION_TYPE = 4194
XTYP_CONNECT_CONFIRM: win32more.Windows.Win32.System.DataExchange.DDE_CLIENT_TRANSACTION_TYPE = 32882
XTYP_DISCONNECT: win32more.Windows.Win32.System.DataExchange.DDE_CLIENT_TRANSACTION_TYPE = 32962
XTYP_MONITOR: win32more.Windows.Win32.System.DataExchange.DDE_CLIENT_TRANSACTION_TYPE = 33010
XTYP_REGISTER: win32more.Windows.Win32.System.DataExchange.DDE_CLIENT_TRANSACTION_TYPE = 32930
XTYP_UNREGISTER: win32more.Windows.Win32.System.DataExchange.DDE_CLIENT_TRANSACTION_TYPE = 32978
XTYP_WILDCONNECT: win32more.Windows.Win32.System.DataExchange.DDE_CLIENT_TRANSACTION_TYPE = 8418
XTYP_XACT_COMPLETE: win32more.Windows.Win32.System.DataExchange.DDE_CLIENT_TRANSACTION_TYPE = 32896
DDE_ENABLE_CALLBACK_CMD = UInt32
EC_ENABLEALL: win32more.Windows.Win32.System.DataExchange.DDE_ENABLE_CALLBACK_CMD = 0
EC_ENABLEONE: win32more.Windows.Win32.System.DataExchange.DDE_ENABLE_CALLBACK_CMD = 128
EC_DISABLE: win32more.Windows.Win32.System.DataExchange.DDE_ENABLE_CALLBACK_CMD = 8
EC_QUERYWAITING: win32more.Windows.Win32.System.DataExchange.DDE_ENABLE_CALLBACK_CMD = 2
DDE_INITIALIZE_COMMAND = UInt32
APPCLASS_MONITOR: win32more.Windows.Win32.System.DataExchange.DDE_INITIALIZE_COMMAND = 1
APPCLASS_STANDARD: win32more.Windows.Win32.System.DataExchange.DDE_INITIALIZE_COMMAND = 0
APPCMD_CLIENTONLY: win32more.Windows.Win32.System.DataExchange.DDE_INITIALIZE_COMMAND = 16
APPCMD_FILTERINITS: win32more.Windows.Win32.System.DataExchange.DDE_INITIALIZE_COMMAND = 32
CBF_FAIL_ALLSVRXACTIONS: win32more.Windows.Win32.System.DataExchange.DDE_INITIALIZE_COMMAND = 258048
CBF_FAIL_ADVISES: win32more.Windows.Win32.System.DataExchange.DDE_INITIALIZE_COMMAND = 16384
CBF_FAIL_CONNECTIONS: win32more.Windows.Win32.System.DataExchange.DDE_INITIALIZE_COMMAND = 8192
CBF_FAIL_EXECUTES: win32more.Windows.Win32.System.DataExchange.DDE_INITIALIZE_COMMAND = 32768
CBF_FAIL_POKES: win32more.Windows.Win32.System.DataExchange.DDE_INITIALIZE_COMMAND = 65536
CBF_FAIL_REQUESTS: win32more.Windows.Win32.System.DataExchange.DDE_INITIALIZE_COMMAND = 131072
CBF_FAIL_SELFCONNECTIONS: win32more.Windows.Win32.System.DataExchange.DDE_INITIALIZE_COMMAND = 4096
CBF_SKIP_ALLNOTIFICATIONS: win32more.Windows.Win32.System.DataExchange.DDE_INITIALIZE_COMMAND = 3932160
CBF_SKIP_CONNECT_CONFIRMS: win32more.Windows.Win32.System.DataExchange.DDE_INITIALIZE_COMMAND = 262144
CBF_SKIP_DISCONNECTS: win32more.Windows.Win32.System.DataExchange.DDE_INITIALIZE_COMMAND = 2097152
CBF_SKIP_REGISTRATIONS: win32more.Windows.Win32.System.DataExchange.DDE_INITIALIZE_COMMAND = 524288
CBF_SKIP_UNREGISTRATIONS: win32more.Windows.Win32.System.DataExchange.DDE_INITIALIZE_COMMAND = 1048576
MF_CALLBACKS: win32more.Windows.Win32.System.DataExchange.DDE_INITIALIZE_COMMAND = 134217728
MF_CONV: win32more.Windows.Win32.System.DataExchange.DDE_INITIALIZE_COMMAND = 1073741824
MF_ERRORS: win32more.Windows.Win32.System.DataExchange.DDE_INITIALIZE_COMMAND = 268435456
MF_HSZ_INFO: win32more.Windows.Win32.System.DataExchange.DDE_INITIALIZE_COMMAND = 16777216
MF_LINKS: win32more.Windows.Win32.System.DataExchange.DDE_INITIALIZE_COMMAND = 536870912
MF_POSTMSGS: win32more.Windows.Win32.System.DataExchange.DDE_INITIALIZE_COMMAND = 67108864
MF_SENDMSGS: win32more.Windows.Win32.System.DataExchange.DDE_INITIALIZE_COMMAND = 33554432
DDE_NAME_SERVICE_CMD = UInt32
DNS_REGISTER: win32more.Windows.Win32.System.DataExchange.DDE_NAME_SERVICE_CMD = 1
DNS_UNREGISTER: win32more.Windows.Win32.System.DataExchange.DDE_NAME_SERVICE_CMD = 2
DNS_FILTERON: win32more.Windows.Win32.System.DataExchange.DDE_NAME_SERVICE_CMD = 4
DNS_FILTEROFF: win32more.Windows.Win32.System.DataExchange.DDE_NAME_SERVICE_CMD = 8
HCONV = VoidPtr
HCONVLIST = VoidPtr
HDDEDATA = VoidPtr
HSZ = VoidPtr
class HSZPAIR(Structure):
    hszSvc: win32more.Windows.Win32.System.DataExchange.HSZ
    hszTopic: win32more.Windows.Win32.System.DataExchange.HSZ
class METAFILEPICT(Structure):
    mm: Int32
    xExt: Int32
    yExt: Int32
    hMF: win32more.Windows.Win32.Graphics.Gdi.HMETAFILE
class MONCBSTRUCT(Structure):
    cb: UInt32
    dwTime: UInt32
    hTask: win32more.Windows.Win32.Foundation.HANDLE
    dwRet: UInt32
    wType: UInt32
    wFmt: UInt32
    hConv: win32more.Windows.Win32.System.DataExchange.HCONV
    hsz1: win32more.Windows.Win32.System.DataExchange.HSZ
    hsz2: win32more.Windows.Win32.System.DataExchange.HSZ
    hData: win32more.Windows.Win32.System.DataExchange.HDDEDATA
    dwData1: UIntPtr
    dwData2: UIntPtr
    cc: win32more.Windows.Win32.System.DataExchange.CONVCONTEXT
    cbData: UInt32
    Data: UInt32 * 8
class MONCONVSTRUCT(Structure):
    cb: UInt32
    fConnect: win32more.Windows.Win32.Foundation.BOOL
    dwTime: UInt32
    hTask: win32more.Windows.Win32.Foundation.HANDLE
    hszSvc: win32more.Windows.Win32.System.DataExchange.HSZ
    hszTopic: win32more.Windows.Win32.System.DataExchange.HSZ
    hConvClient: win32more.Windows.Win32.System.DataExchange.HCONV
    hConvServer: win32more.Windows.Win32.System.DataExchange.HCONV
class MONERRSTRUCT(Structure):
    cb: UInt32
    wLastError: UInt32
    dwTime: UInt32
    hTask: win32more.Windows.Win32.Foundation.HANDLE
class MONHSZSTRUCTA(Structure):
    cb: UInt32
    fsAction: win32more.Windows.Win32.Foundation.BOOL
    dwTime: UInt32
    hsz: win32more.Windows.Win32.System.DataExchange.HSZ
    hTask: win32more.Windows.Win32.Foundation.HANDLE
    str: win32more.Windows.Win32.Foundation.CHAR * 1
class MONHSZSTRUCTW(Structure):
    cb: UInt32
    fsAction: win32more.Windows.Win32.Foundation.BOOL
    dwTime: UInt32
    hsz: win32more.Windows.Win32.System.DataExchange.HSZ
    hTask: win32more.Windows.Win32.Foundation.HANDLE
    str: Char * 1
MONHSZSTRUCT = UnicodeAlias('MONHSZSTRUCTW')
class MONLINKSTRUCT(Structure):
    cb: UInt32
    dwTime: UInt32
    hTask: win32more.Windows.Win32.Foundation.HANDLE
    fEstablished: win32more.Windows.Win32.Foundation.BOOL
    fNoData: win32more.Windows.Win32.Foundation.BOOL
    hszSvc: win32more.Windows.Win32.System.DataExchange.HSZ
    hszTopic: win32more.Windows.Win32.System.DataExchange.HSZ
    hszItem: win32more.Windows.Win32.System.DataExchange.HSZ
    wFmt: UInt32
    fServer: win32more.Windows.Win32.Foundation.BOOL
    hConvServer: win32more.Windows.Win32.System.DataExchange.HCONV
    hConvClient: win32more.Windows.Win32.System.DataExchange.HCONV
class MONMSGSTRUCT(Structure):
    cb: UInt32
    hwndTo: win32more.Windows.Win32.Foundation.HWND
    dwTime: UInt32
    hTask: win32more.Windows.Win32.Foundation.HANDLE
    wMsg: UInt32
    wParam: win32more.Windows.Win32.Foundation.WPARAM
    lParam: win32more.Windows.Win32.Foundation.LPARAM
    dmhd: win32more.Windows.Win32.System.DataExchange.DDEML_MSG_HOOK_DATA
@winfunctype_pointer
def PFNCALLBACK(wType: UInt32, wFmt: UInt32, hConv: win32more.Windows.Win32.System.DataExchange.HCONV, hsz1: win32more.Windows.Win32.System.DataExchange.HSZ, hsz2: win32more.Windows.Win32.System.DataExchange.HSZ, hData: win32more.Windows.Win32.System.DataExchange.HDDEDATA, dwData1: UIntPtr, dwData2: UIntPtr) -> win32more.Windows.Win32.System.DataExchange.HDDEDATA: ...


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.Foundation
import win32more.Windows.Foundation.Collections
import win32more.Windows.Networking
import win32more.Windows.Networking.XboxLive
import win32more.Windows.Storage.Streams
import win32more.Windows.Win32.System.WinRT
class IXboxLiveDeviceAddress(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Networking.XboxLive.IXboxLiveDeviceAddress'
    _iid_ = Guid('{f5bbd279-3c86-4b57-a31a-b9462408fd01}')
    @winrt_commethod(6)
    def add_SnapshotChanged(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Networking.XboxLive.XboxLiveDeviceAddress, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(7)
    def remove_SnapshotChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(8)
    def GetSnapshotAsBase64(self) -> WinRT_String: ...
    @winrt_commethod(9)
    def GetSnapshotAsBuffer(self) -> win32more.Windows.Storage.Streams.IBuffer: ...
    @winrt_commethod(10)
    def GetSnapshotAsBytes(self, buffer: FillArray[Byte], bytesWritten: POINTER(UInt32)) -> Void: ...
    @winrt_commethod(11)
    def Compare(self, otherDeviceAddress: win32more.Windows.Networking.XboxLive.XboxLiveDeviceAddress) -> Int32: ...
    @winrt_commethod(12)
    def get_IsValid(self) -> Boolean: ...
    @winrt_commethod(13)
    def get_IsLocal(self) -> Boolean: ...
    @winrt_commethod(14)
    def get_NetworkAccessKind(self) -> win32more.Windows.Networking.XboxLive.XboxLiveNetworkAccessKind: ...
    IsLocal = property(get_IsLocal, None)
    IsValid = property(get_IsValid, None)
    NetworkAccessKind = property(get_NetworkAccessKind, None)
    SnapshotChanged = event()
class IXboxLiveDeviceAddressStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Networking.XboxLive.IXboxLiveDeviceAddressStatics'
    _iid_ = Guid('{5954a819-4a79-4931-827c-7f503e963263}')
    @winrt_commethod(6)
    def CreateFromSnapshotBase64(self, base64: WinRT_String) -> win32more.Windows.Networking.XboxLive.XboxLiveDeviceAddress: ...
    @winrt_commethod(7)
    def CreateFromSnapshotBuffer(self, buffer: win32more.Windows.Storage.Streams.IBuffer) -> win32more.Windows.Networking.XboxLive.XboxLiveDeviceAddress: ...
    @winrt_commethod(8)
    def CreateFromSnapshotBytes(self, buffer: PassArray[Byte]) -> win32more.Windows.Networking.XboxLive.XboxLiveDeviceAddress: ...
    @winrt_commethod(9)
    def GetLocal(self) -> win32more.Windows.Networking.XboxLive.XboxLiveDeviceAddress: ...
    @winrt_commethod(10)
    def get_MaxSnapshotBytesSize(self) -> UInt32: ...
    MaxSnapshotBytesSize = property(get_MaxSnapshotBytesSize, None)
class IXboxLiveEndpointPair(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Networking.XboxLive.IXboxLiveEndpointPair'
    _iid_ = Guid('{1e9a839b-813e-44e0-b87f-c87a093475e4}')
    @winrt_commethod(6)
    def add_StateChanged(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Networking.XboxLive.XboxLiveEndpointPair, win32more.Windows.Networking.XboxLive.XboxLiveEndpointPairStateChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(7)
    def remove_StateChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(8)
    def DeleteAsync(self) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_commethod(9)
    def GetRemoteSocketAddressBytes(self, socketAddress: FillArray[Byte]) -> Void: ...
    @winrt_commethod(10)
    def GetLocalSocketAddressBytes(self, socketAddress: FillArray[Byte]) -> Void: ...
    @winrt_commethod(11)
    def get_State(self) -> win32more.Windows.Networking.XboxLive.XboxLiveEndpointPairState: ...
    @winrt_commethod(12)
    def get_Template(self) -> win32more.Windows.Networking.XboxLive.XboxLiveEndpointPairTemplate: ...
    @winrt_commethod(13)
    def get_RemoteDeviceAddress(self) -> win32more.Windows.Networking.XboxLive.XboxLiveDeviceAddress: ...
    @winrt_commethod(14)
    def get_RemoteHostName(self) -> win32more.Windows.Networking.HostName: ...
    @winrt_commethod(15)
    def get_RemotePort(self) -> WinRT_String: ...
    @winrt_commethod(16)
    def get_LocalHostName(self) -> win32more.Windows.Networking.HostName: ...
    @winrt_commethod(17)
    def get_LocalPort(self) -> WinRT_String: ...
    LocalHostName = property(get_LocalHostName, None)
    LocalPort = property(get_LocalPort, None)
    RemoteDeviceAddress = property(get_RemoteDeviceAddress, None)
    RemoteHostName = property(get_RemoteHostName, None)
    RemotePort = property(get_RemotePort, None)
    State = property(get_State, None)
    Template = property(get_Template, None)
    StateChanged = event()
class IXboxLiveEndpointPairCreationResult(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Networking.XboxLive.IXboxLiveEndpointPairCreationResult'
    _iid_ = Guid('{d9a8bb95-2aab-4d1e-9794-33ecc0dcf0fe}')
    @winrt_commethod(6)
    def get_DeviceAddress(self) -> win32more.Windows.Networking.XboxLive.XboxLiveDeviceAddress: ...
    @winrt_commethod(7)
    def get_Status(self) -> win32more.Windows.Networking.XboxLive.XboxLiveEndpointPairCreationStatus: ...
    @winrt_commethod(8)
    def get_IsExistingPathEvaluation(self) -> Boolean: ...
    @winrt_commethod(9)
    def get_EndpointPair(self) -> win32more.Windows.Networking.XboxLive.XboxLiveEndpointPair: ...
    DeviceAddress = property(get_DeviceAddress, None)
    EndpointPair = property(get_EndpointPair, None)
    IsExistingPathEvaluation = property(get_IsExistingPathEvaluation, None)
    Status = property(get_Status, None)
class IXboxLiveEndpointPairStateChangedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Networking.XboxLive.IXboxLiveEndpointPairStateChangedEventArgs'
    _iid_ = Guid('{592e3b55-de08-44e7-ac3b-b9b9a169583a}')
    @winrt_commethod(6)
    def get_OldState(self) -> win32more.Windows.Networking.XboxLive.XboxLiveEndpointPairState: ...
    @winrt_commethod(7)
    def get_NewState(self) -> win32more.Windows.Networking.XboxLive.XboxLiveEndpointPairState: ...
    NewState = property(get_NewState, None)
    OldState = property(get_OldState, None)
class IXboxLiveEndpointPairStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Networking.XboxLive.IXboxLiveEndpointPairStatics'
    _iid_ = Guid('{64316b30-217a-4243-8ee1-6729281d27db}')
    @winrt_commethod(6)
    def FindEndpointPairBySocketAddressBytes(self, localSocketAddress: PassArray[Byte], remoteSocketAddress: PassArray[Byte]) -> win32more.Windows.Networking.XboxLive.XboxLiveEndpointPair: ...
    @winrt_commethod(7)
    def FindEndpointPairByHostNamesAndPorts(self, localHostName: win32more.Windows.Networking.HostName, localPort: WinRT_String, remoteHostName: win32more.Windows.Networking.HostName, remotePort: WinRT_String) -> win32more.Windows.Networking.XboxLive.XboxLiveEndpointPair: ...
class IXboxLiveEndpointPairTemplate(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Networking.XboxLive.IXboxLiveEndpointPairTemplate'
    _iid_ = Guid('{6b286ecf-3457-40ce-b9a1-c0cfe0213ea7}')
    @winrt_commethod(6)
    def add_InboundEndpointPairCreated(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Networking.XboxLive.XboxLiveEndpointPairTemplate, win32more.Windows.Networking.XboxLive.XboxLiveInboundEndpointPairCreatedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(7)
    def remove_InboundEndpointPairCreated(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(8)
    def CreateEndpointPairDefaultAsync(self, deviceAddress: win32more.Windows.Networking.XboxLive.XboxLiveDeviceAddress) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Networking.XboxLive.XboxLiveEndpointPairCreationResult]: ...
    @winrt_commethod(9)
    def CreateEndpointPairWithBehaviorsAsync(self, deviceAddress: win32more.Windows.Networking.XboxLive.XboxLiveDeviceAddress, behaviors: win32more.Windows.Networking.XboxLive.XboxLiveEndpointPairCreationBehaviors) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Networking.XboxLive.XboxLiveEndpointPairCreationResult]: ...
    @winrt_commethod(10)
    def CreateEndpointPairForPortsDefaultAsync(self, deviceAddress: win32more.Windows.Networking.XboxLive.XboxLiveDeviceAddress, initiatorPort: WinRT_String, acceptorPort: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Networking.XboxLive.XboxLiveEndpointPairCreationResult]: ...
    @winrt_commethod(11)
    def CreateEndpointPairForPortsWithBehaviorsAsync(self, deviceAddress: win32more.Windows.Networking.XboxLive.XboxLiveDeviceAddress, initiatorPort: WinRT_String, acceptorPort: WinRT_String, behaviors: win32more.Windows.Networking.XboxLive.XboxLiveEndpointPairCreationBehaviors) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Networking.XboxLive.XboxLiveEndpointPairCreationResult]: ...
    @winrt_commethod(12)
    def get_Name(self) -> WinRT_String: ...
    @winrt_commethod(13)
    def get_SocketKind(self) -> win32more.Windows.Networking.XboxLive.XboxLiveSocketKind: ...
    @winrt_commethod(14)
    def get_InitiatorBoundPortRangeLower(self) -> UInt16: ...
    @winrt_commethod(15)
    def get_InitiatorBoundPortRangeUpper(self) -> UInt16: ...
    @winrt_commethod(16)
    def get_AcceptorBoundPortRangeLower(self) -> UInt16: ...
    @winrt_commethod(17)
    def get_AcceptorBoundPortRangeUpper(self) -> UInt16: ...
    @winrt_commethod(18)
    def get_EndpointPairs(self) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Networking.XboxLive.XboxLiveEndpointPair]: ...
    AcceptorBoundPortRangeLower = property(get_AcceptorBoundPortRangeLower, None)
    AcceptorBoundPortRangeUpper = property(get_AcceptorBoundPortRangeUpper, None)
    EndpointPairs = property(get_EndpointPairs, None)
    InitiatorBoundPortRangeLower = property(get_InitiatorBoundPortRangeLower, None)
    InitiatorBoundPortRangeUpper = property(get_InitiatorBoundPortRangeUpper, None)
    Name = property(get_Name, None)
    SocketKind = property(get_SocketKind, None)
    InboundEndpointPairCreated = event()
class IXboxLiveEndpointPairTemplateStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Networking.XboxLive.IXboxLiveEndpointPairTemplateStatics'
    _iid_ = Guid('{1e13137b-737b-4a23-bc64-0870f75655ba}')
    @winrt_commethod(6)
    def GetTemplateByName(self, name: WinRT_String) -> win32more.Windows.Networking.XboxLive.XboxLiveEndpointPairTemplate: ...
    @winrt_commethod(7)
    def get_Templates(self) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Networking.XboxLive.XboxLiveEndpointPairTemplate]: ...
    Templates = property(get_Templates, None)
class IXboxLiveInboundEndpointPairCreatedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Networking.XboxLive.IXboxLiveInboundEndpointPairCreatedEventArgs'
    _iid_ = Guid('{dc183b62-22ba-48d2-80de-c23968bd198b}')
    @winrt_commethod(6)
    def get_EndpointPair(self) -> win32more.Windows.Networking.XboxLive.XboxLiveEndpointPair: ...
    EndpointPair = property(get_EndpointPair, None)
class IXboxLiveQualityOfServiceMeasurement(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Networking.XboxLive.IXboxLiveQualityOfServiceMeasurement'
    _iid_ = Guid('{4d682bce-a5d6-47e6-a236-cfde5fbdf2ed}')
    @winrt_commethod(6)
    def MeasureAsync(self) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_commethod(7)
    def GetMetricResultsForDevice(self, deviceAddress: win32more.Windows.Networking.XboxLive.XboxLiveDeviceAddress) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Networking.XboxLive.XboxLiveQualityOfServiceMetricResult]: ...
    @winrt_commethod(8)
    def GetMetricResultsForMetric(self, metric: win32more.Windows.Networking.XboxLive.XboxLiveQualityOfServiceMetric) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Networking.XboxLive.XboxLiveQualityOfServiceMetricResult]: ...
    @winrt_commethod(9)
    def GetMetricResult(self, deviceAddress: win32more.Windows.Networking.XboxLive.XboxLiveDeviceAddress, metric: win32more.Windows.Networking.XboxLive.XboxLiveQualityOfServiceMetric) -> win32more.Windows.Networking.XboxLive.XboxLiveQualityOfServiceMetricResult: ...
    @winrt_commethod(10)
    def GetPrivatePayloadResult(self, deviceAddress: win32more.Windows.Networking.XboxLive.XboxLiveDeviceAddress) -> win32more.Windows.Networking.XboxLive.XboxLiveQualityOfServicePrivatePayloadResult: ...
    @winrt_commethod(11)
    def get_Metrics(self) -> win32more.Windows.Foundation.Collections.IVector[win32more.Windows.Networking.XboxLive.XboxLiveQualityOfServiceMetric]: ...
    @winrt_commethod(12)
    def get_DeviceAddresses(self) -> win32more.Windows.Foundation.Collections.IVector[win32more.Windows.Networking.XboxLive.XboxLiveDeviceAddress]: ...
    @winrt_commethod(13)
    def get_ShouldRequestPrivatePayloads(self) -> Boolean: ...
    @winrt_commethod(14)
    def put_ShouldRequestPrivatePayloads(self, value: Boolean) -> Void: ...
    @winrt_commethod(15)
    def get_TimeoutInMilliseconds(self) -> UInt32: ...
    @winrt_commethod(16)
    def put_TimeoutInMilliseconds(self, value: UInt32) -> Void: ...
    @winrt_commethod(17)
    def get_NumberOfProbesToAttempt(self) -> UInt32: ...
    @winrt_commethod(18)
    def put_NumberOfProbesToAttempt(self, value: UInt32) -> Void: ...
    @winrt_commethod(19)
    def get_NumberOfResultsPending(self) -> UInt32: ...
    @winrt_commethod(20)
    def get_MetricResults(self) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Networking.XboxLive.XboxLiveQualityOfServiceMetricResult]: ...
    @winrt_commethod(21)
    def get_PrivatePayloadResults(self) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Networking.XboxLive.XboxLiveQualityOfServicePrivatePayloadResult]: ...
    DeviceAddresses = property(get_DeviceAddresses, None)
    MetricResults = property(get_MetricResults, None)
    Metrics = property(get_Metrics, None)
    NumberOfProbesToAttempt = property(get_NumberOfProbesToAttempt, put_NumberOfProbesToAttempt)
    NumberOfResultsPending = property(get_NumberOfResultsPending, None)
    PrivatePayloadResults = property(get_PrivatePayloadResults, None)
    ShouldRequestPrivatePayloads = property(get_ShouldRequestPrivatePayloads, put_ShouldRequestPrivatePayloads)
    TimeoutInMilliseconds = property(get_TimeoutInMilliseconds, put_TimeoutInMilliseconds)
class IXboxLiveQualityOfServiceMeasurementStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Networking.XboxLive.IXboxLiveQualityOfServiceMeasurementStatics'
    _iid_ = Guid('{6e352dca-23cf-440a-b077-5e30857a8234}')
    @winrt_commethod(6)
    def PublishPrivatePayloadBytes(self, payload: PassArray[Byte]) -> Void: ...
    @winrt_commethod(7)
    def ClearPrivatePayload(self) -> Void: ...
    @winrt_commethod(8)
    def get_MaxSimultaneousProbeConnections(self) -> UInt32: ...
    @winrt_commethod(9)
    def put_MaxSimultaneousProbeConnections(self, value: UInt32) -> Void: ...
    @winrt_commethod(10)
    def get_IsSystemOutboundBandwidthConstrained(self) -> Boolean: ...
    @winrt_commethod(11)
    def put_IsSystemOutboundBandwidthConstrained(self, value: Boolean) -> Void: ...
    @winrt_commethod(12)
    def get_IsSystemInboundBandwidthConstrained(self) -> Boolean: ...
    @winrt_commethod(13)
    def put_IsSystemInboundBandwidthConstrained(self, value: Boolean) -> Void: ...
    @winrt_commethod(14)
    def get_PublishedPrivatePayload(self) -> win32more.Windows.Storage.Streams.IBuffer: ...
    @winrt_commethod(15)
    def put_PublishedPrivatePayload(self, value: win32more.Windows.Storage.Streams.IBuffer) -> Void: ...
    @winrt_commethod(16)
    def get_MaxPrivatePayloadSize(self) -> UInt32: ...
    IsSystemInboundBandwidthConstrained = property(get_IsSystemInboundBandwidthConstrained, put_IsSystemInboundBandwidthConstrained)
    IsSystemOutboundBandwidthConstrained = property(get_IsSystemOutboundBandwidthConstrained, put_IsSystemOutboundBandwidthConstrained)
    MaxPrivatePayloadSize = property(get_MaxPrivatePayloadSize, None)
    MaxSimultaneousProbeConnections = property(get_MaxSimultaneousProbeConnections, put_MaxSimultaneousProbeConnections)
    PublishedPrivatePayload = property(get_PublishedPrivatePayload, put_PublishedPrivatePayload)
class IXboxLiveQualityOfServiceMetricResult(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Networking.XboxLive.IXboxLiveQualityOfServiceMetricResult'
    _iid_ = Guid('{aeec53d1-3561-4782-b0cf-d3ae29d9fa87}')
    @winrt_commethod(6)
    def get_Status(self) -> win32more.Windows.Networking.XboxLive.XboxLiveQualityOfServiceMeasurementStatus: ...
    @winrt_commethod(7)
    def get_DeviceAddress(self) -> win32more.Windows.Networking.XboxLive.XboxLiveDeviceAddress: ...
    @winrt_commethod(8)
    def get_Metric(self) -> win32more.Windows.Networking.XboxLive.XboxLiveQualityOfServiceMetric: ...
    @winrt_commethod(9)
    def get_Value(self) -> UInt64: ...
    DeviceAddress = property(get_DeviceAddress, None)
    Metric = property(get_Metric, None)
    Status = property(get_Status, None)
    Value = property(get_Value, None)
class IXboxLiveQualityOfServicePrivatePayloadResult(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Networking.XboxLive.IXboxLiveQualityOfServicePrivatePayloadResult'
    _iid_ = Guid('{5a6302ae-6f38-41c0-9fcc-ea6cb978cafc}')
    @winrt_commethod(6)
    def get_Status(self) -> win32more.Windows.Networking.XboxLive.XboxLiveQualityOfServiceMeasurementStatus: ...
    @winrt_commethod(7)
    def get_DeviceAddress(self) -> win32more.Windows.Networking.XboxLive.XboxLiveDeviceAddress: ...
    @winrt_commethod(8)
    def get_Value(self) -> win32more.Windows.Storage.Streams.IBuffer: ...
    DeviceAddress = property(get_DeviceAddress, None)
    Status = property(get_Status, None)
    Value = property(get_Value, None)
class _XboxLiveDeviceAddress_Meta_(ComPtr.__class__):
    pass
class XboxLiveDeviceAddress(ComPtr, metaclass=_XboxLiveDeviceAddress_Meta_):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Networking.XboxLive.IXboxLiveDeviceAddress
    _classid_ = 'Windows.Networking.XboxLive.XboxLiveDeviceAddress'
    @winrt_mixinmethod
    def add_SnapshotChanged(self: win32more.Windows.Networking.XboxLive.IXboxLiveDeviceAddress, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Networking.XboxLive.XboxLiveDeviceAddress, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_SnapshotChanged(self: win32more.Windows.Networking.XboxLive.IXboxLiveDeviceAddress, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def GetSnapshotAsBase64(self: win32more.Windows.Networking.XboxLive.IXboxLiveDeviceAddress) -> WinRT_String: ...
    @winrt_mixinmethod
    def GetSnapshotAsBuffer(self: win32more.Windows.Networking.XboxLive.IXboxLiveDeviceAddress) -> win32more.Windows.Storage.Streams.IBuffer: ...
    @winrt_mixinmethod
    def GetSnapshotAsBytes(self: win32more.Windows.Networking.XboxLive.IXboxLiveDeviceAddress, buffer: FillArray[Byte], bytesWritten: POINTER(UInt32)) -> Void: ...
    @winrt_mixinmethod
    def Compare(self: win32more.Windows.Networking.XboxLive.IXboxLiveDeviceAddress, otherDeviceAddress: win32more.Windows.Networking.XboxLive.XboxLiveDeviceAddress) -> Int32: ...
    @winrt_mixinmethod
    def get_IsValid(self: win32more.Windows.Networking.XboxLive.IXboxLiveDeviceAddress) -> Boolean: ...
    @winrt_mixinmethod
    def get_IsLocal(self: win32more.Windows.Networking.XboxLive.IXboxLiveDeviceAddress) -> Boolean: ...
    @winrt_mixinmethod
    def get_NetworkAccessKind(self: win32more.Windows.Networking.XboxLive.IXboxLiveDeviceAddress) -> win32more.Windows.Networking.XboxLive.XboxLiveNetworkAccessKind: ...
    @winrt_classmethod
    def CreateFromSnapshotBase64(cls: win32more.Windows.Networking.XboxLive.IXboxLiveDeviceAddressStatics, base64: WinRT_String) -> win32more.Windows.Networking.XboxLive.XboxLiveDeviceAddress: ...
    @winrt_classmethod
    def CreateFromSnapshotBuffer(cls: win32more.Windows.Networking.XboxLive.IXboxLiveDeviceAddressStatics, buffer: win32more.Windows.Storage.Streams.IBuffer) -> win32more.Windows.Networking.XboxLive.XboxLiveDeviceAddress: ...
    @winrt_classmethod
    def CreateFromSnapshotBytes(cls: win32more.Windows.Networking.XboxLive.IXboxLiveDeviceAddressStatics, buffer: PassArray[Byte]) -> win32more.Windows.Networking.XboxLive.XboxLiveDeviceAddress: ...
    @winrt_classmethod
    def GetLocal(cls: win32more.Windows.Networking.XboxLive.IXboxLiveDeviceAddressStatics) -> win32more.Windows.Networking.XboxLive.XboxLiveDeviceAddress: ...
    @winrt_classmethod
    def get_MaxSnapshotBytesSize(cls: win32more.Windows.Networking.XboxLive.IXboxLiveDeviceAddressStatics) -> UInt32: ...
    IsLocal = property(get_IsLocal, None)
    IsValid = property(get_IsValid, None)
    NetworkAccessKind = property(get_NetworkAccessKind, None)
    _XboxLiveDeviceAddress_Meta_.MaxSnapshotBytesSize = property(get_MaxSnapshotBytesSize, None)
    SnapshotChanged = event()
class XboxLiveEndpointPair(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Networking.XboxLive.IXboxLiveEndpointPair
    _classid_ = 'Windows.Networking.XboxLive.XboxLiveEndpointPair'
    @winrt_mixinmethod
    def add_StateChanged(self: win32more.Windows.Networking.XboxLive.IXboxLiveEndpointPair, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Networking.XboxLive.XboxLiveEndpointPair, win32more.Windows.Networking.XboxLive.XboxLiveEndpointPairStateChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_StateChanged(self: win32more.Windows.Networking.XboxLive.IXboxLiveEndpointPair, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def DeleteAsync(self: win32more.Windows.Networking.XboxLive.IXboxLiveEndpointPair) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_mixinmethod
    def GetRemoteSocketAddressBytes(self: win32more.Windows.Networking.XboxLive.IXboxLiveEndpointPair, socketAddress: FillArray[Byte]) -> Void: ...
    @winrt_mixinmethod
    def GetLocalSocketAddressBytes(self: win32more.Windows.Networking.XboxLive.IXboxLiveEndpointPair, socketAddress: FillArray[Byte]) -> Void: ...
    @winrt_mixinmethod
    def get_State(self: win32more.Windows.Networking.XboxLive.IXboxLiveEndpointPair) -> win32more.Windows.Networking.XboxLive.XboxLiveEndpointPairState: ...
    @winrt_mixinmethod
    def get_Template(self: win32more.Windows.Networking.XboxLive.IXboxLiveEndpointPair) -> win32more.Windows.Networking.XboxLive.XboxLiveEndpointPairTemplate: ...
    @winrt_mixinmethod
    def get_RemoteDeviceAddress(self: win32more.Windows.Networking.XboxLive.IXboxLiveEndpointPair) -> win32more.Windows.Networking.XboxLive.XboxLiveDeviceAddress: ...
    @winrt_mixinmethod
    def get_RemoteHostName(self: win32more.Windows.Networking.XboxLive.IXboxLiveEndpointPair) -> win32more.Windows.Networking.HostName: ...
    @winrt_mixinmethod
    def get_RemotePort(self: win32more.Windows.Networking.XboxLive.IXboxLiveEndpointPair) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_LocalHostName(self: win32more.Windows.Networking.XboxLive.IXboxLiveEndpointPair) -> win32more.Windows.Networking.HostName: ...
    @winrt_mixinmethod
    def get_LocalPort(self: win32more.Windows.Networking.XboxLive.IXboxLiveEndpointPair) -> WinRT_String: ...
    @winrt_classmethod
    def FindEndpointPairBySocketAddressBytes(cls: win32more.Windows.Networking.XboxLive.IXboxLiveEndpointPairStatics, localSocketAddress: PassArray[Byte], remoteSocketAddress: PassArray[Byte]) -> win32more.Windows.Networking.XboxLive.XboxLiveEndpointPair: ...
    @winrt_classmethod
    def FindEndpointPairByHostNamesAndPorts(cls: win32more.Windows.Networking.XboxLive.IXboxLiveEndpointPairStatics, localHostName: win32more.Windows.Networking.HostName, localPort: WinRT_String, remoteHostName: win32more.Windows.Networking.HostName, remotePort: WinRT_String) -> win32more.Windows.Networking.XboxLive.XboxLiveEndpointPair: ...
    LocalHostName = property(get_LocalHostName, None)
    LocalPort = property(get_LocalPort, None)
    RemoteDeviceAddress = property(get_RemoteDeviceAddress, None)
    RemoteHostName = property(get_RemoteHostName, None)
    RemotePort = property(get_RemotePort, None)
    State = property(get_State, None)
    Template = property(get_Template, None)
    StateChanged = event()
class XboxLiveEndpointPairCreationBehaviors(Enum, UInt32):
    None_ = 0
    ReevaluatePath = 1
class XboxLiveEndpointPairCreationResult(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Networking.XboxLive.IXboxLiveEndpointPairCreationResult
    _classid_ = 'Windows.Networking.XboxLive.XboxLiveEndpointPairCreationResult'
    @winrt_mixinmethod
    def get_DeviceAddress(self: win32more.Windows.Networking.XboxLive.IXboxLiveEndpointPairCreationResult) -> win32more.Windows.Networking.XboxLive.XboxLiveDeviceAddress: ...
    @winrt_mixinmethod
    def get_Status(self: win32more.Windows.Networking.XboxLive.IXboxLiveEndpointPairCreationResult) -> win32more.Windows.Networking.XboxLive.XboxLiveEndpointPairCreationStatus: ...
    @winrt_mixinmethod
    def get_IsExistingPathEvaluation(self: win32more.Windows.Networking.XboxLive.IXboxLiveEndpointPairCreationResult) -> Boolean: ...
    @winrt_mixinmethod
    def get_EndpointPair(self: win32more.Windows.Networking.XboxLive.IXboxLiveEndpointPairCreationResult) -> win32more.Windows.Networking.XboxLive.XboxLiveEndpointPair: ...
    DeviceAddress = property(get_DeviceAddress, None)
    EndpointPair = property(get_EndpointPair, None)
    IsExistingPathEvaluation = property(get_IsExistingPathEvaluation, None)
    Status = property(get_Status, None)
class XboxLiveEndpointPairCreationStatus(Enum, Int32):
    Succeeded = 0
    NoLocalNetworks = 1
    NoCompatibleNetworkPaths = 2
    LocalSystemNotAuthorized = 3
    Canceled = 4
    TimedOut = 5
    RemoteSystemNotAuthorized = 6
    RefusedDueToConfiguration = 7
    UnexpectedInternalError = 8
class XboxLiveEndpointPairState(Enum, Int32):
    Invalid = 0
    CreatingOutbound = 1
    CreatingInbound = 2
    Ready = 3
    DeletingLocally = 4
    RemoteEndpointTerminating = 5
    Deleted = 6
class XboxLiveEndpointPairStateChangedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Networking.XboxLive.IXboxLiveEndpointPairStateChangedEventArgs
    _classid_ = 'Windows.Networking.XboxLive.XboxLiveEndpointPairStateChangedEventArgs'
    @winrt_mixinmethod
    def get_OldState(self: win32more.Windows.Networking.XboxLive.IXboxLiveEndpointPairStateChangedEventArgs) -> win32more.Windows.Networking.XboxLive.XboxLiveEndpointPairState: ...
    @winrt_mixinmethod
    def get_NewState(self: win32more.Windows.Networking.XboxLive.IXboxLiveEndpointPairStateChangedEventArgs) -> win32more.Windows.Networking.XboxLive.XboxLiveEndpointPairState: ...
    NewState = property(get_NewState, None)
    OldState = property(get_OldState, None)
class _XboxLiveEndpointPairTemplate_Meta_(ComPtr.__class__):
    pass
class XboxLiveEndpointPairTemplate(ComPtr, metaclass=_XboxLiveEndpointPairTemplate_Meta_):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Networking.XboxLive.IXboxLiveEndpointPairTemplate
    _classid_ = 'Windows.Networking.XboxLive.XboxLiveEndpointPairTemplate'
    @winrt_mixinmethod
    def add_InboundEndpointPairCreated(self: win32more.Windows.Networking.XboxLive.IXboxLiveEndpointPairTemplate, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Networking.XboxLive.XboxLiveEndpointPairTemplate, win32more.Windows.Networking.XboxLive.XboxLiveInboundEndpointPairCreatedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_InboundEndpointPairCreated(self: win32more.Windows.Networking.XboxLive.IXboxLiveEndpointPairTemplate, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def CreateEndpointPairDefaultAsync(self: win32more.Windows.Networking.XboxLive.IXboxLiveEndpointPairTemplate, deviceAddress: win32more.Windows.Networking.XboxLive.XboxLiveDeviceAddress) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Networking.XboxLive.XboxLiveEndpointPairCreationResult]: ...
    @winrt_mixinmethod
    def CreateEndpointPairWithBehaviorsAsync(self: win32more.Windows.Networking.XboxLive.IXboxLiveEndpointPairTemplate, deviceAddress: win32more.Windows.Networking.XboxLive.XboxLiveDeviceAddress, behaviors: win32more.Windows.Networking.XboxLive.XboxLiveEndpointPairCreationBehaviors) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Networking.XboxLive.XboxLiveEndpointPairCreationResult]: ...
    @winrt_mixinmethod
    def CreateEndpointPairForPortsDefaultAsync(self: win32more.Windows.Networking.XboxLive.IXboxLiveEndpointPairTemplate, deviceAddress: win32more.Windows.Networking.XboxLive.XboxLiveDeviceAddress, initiatorPort: WinRT_String, acceptorPort: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Networking.XboxLive.XboxLiveEndpointPairCreationResult]: ...
    @winrt_mixinmethod
    def CreateEndpointPairForPortsWithBehaviorsAsync(self: win32more.Windows.Networking.XboxLive.IXboxLiveEndpointPairTemplate, deviceAddress: win32more.Windows.Networking.XboxLive.XboxLiveDeviceAddress, initiatorPort: WinRT_String, acceptorPort: WinRT_String, behaviors: win32more.Windows.Networking.XboxLive.XboxLiveEndpointPairCreationBehaviors) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Networking.XboxLive.XboxLiveEndpointPairCreationResult]: ...
    @winrt_mixinmethod
    def get_Name(self: win32more.Windows.Networking.XboxLive.IXboxLiveEndpointPairTemplate) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_SocketKind(self: win32more.Windows.Networking.XboxLive.IXboxLiveEndpointPairTemplate) -> win32more.Windows.Networking.XboxLive.XboxLiveSocketKind: ...
    @winrt_mixinmethod
    def get_InitiatorBoundPortRangeLower(self: win32more.Windows.Networking.XboxLive.IXboxLiveEndpointPairTemplate) -> UInt16: ...
    @winrt_mixinmethod
    def get_InitiatorBoundPortRangeUpper(self: win32more.Windows.Networking.XboxLive.IXboxLiveEndpointPairTemplate) -> UInt16: ...
    @winrt_mixinmethod
    def get_AcceptorBoundPortRangeLower(self: win32more.Windows.Networking.XboxLive.IXboxLiveEndpointPairTemplate) -> UInt16: ...
    @winrt_mixinmethod
    def get_AcceptorBoundPortRangeUpper(self: win32more.Windows.Networking.XboxLive.IXboxLiveEndpointPairTemplate) -> UInt16: ...
    @winrt_mixinmethod
    def get_EndpointPairs(self: win32more.Windows.Networking.XboxLive.IXboxLiveEndpointPairTemplate) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Networking.XboxLive.XboxLiveEndpointPair]: ...
    @winrt_classmethod
    def GetTemplateByName(cls: win32more.Windows.Networking.XboxLive.IXboxLiveEndpointPairTemplateStatics, name: WinRT_String) -> win32more.Windows.Networking.XboxLive.XboxLiveEndpointPairTemplate: ...
    @winrt_classmethod
    def get_Templates(cls: win32more.Windows.Networking.XboxLive.IXboxLiveEndpointPairTemplateStatics) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Networking.XboxLive.XboxLiveEndpointPairTemplate]: ...
    AcceptorBoundPortRangeLower = property(get_AcceptorBoundPortRangeLower, None)
    AcceptorBoundPortRangeUpper = property(get_AcceptorBoundPortRangeUpper, None)
    EndpointPairs = property(get_EndpointPairs, None)
    InitiatorBoundPortRangeLower = property(get_InitiatorBoundPortRangeLower, None)
    InitiatorBoundPortRangeUpper = property(get_InitiatorBoundPortRangeUpper, None)
    Name = property(get_Name, None)
    SocketKind = property(get_SocketKind, None)
    _XboxLiveEndpointPairTemplate_Meta_.Templates = property(get_Templates, None)
    InboundEndpointPairCreated = event()
class XboxLiveInboundEndpointPairCreatedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Networking.XboxLive.IXboxLiveInboundEndpointPairCreatedEventArgs
    _classid_ = 'Windows.Networking.XboxLive.XboxLiveInboundEndpointPairCreatedEventArgs'
    @winrt_mixinmethod
    def get_EndpointPair(self: win32more.Windows.Networking.XboxLive.IXboxLiveInboundEndpointPairCreatedEventArgs) -> win32more.Windows.Networking.XboxLive.XboxLiveEndpointPair: ...
    EndpointPair = property(get_EndpointPair, None)
class XboxLiveNetworkAccessKind(Enum, Int32):
    Open = 0
    Moderate = 1
    Strict = 2
class _XboxLiveQualityOfServiceMeasurement_Meta_(ComPtr.__class__):
    pass
class XboxLiveQualityOfServiceMeasurement(ComPtr, metaclass=_XboxLiveQualityOfServiceMeasurement_Meta_):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Networking.XboxLive.IXboxLiveQualityOfServiceMeasurement
    _classid_ = 'Windows.Networking.XboxLive.XboxLiveQualityOfServiceMeasurement'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.Networking.XboxLive.XboxLiveQualityOfServiceMeasurement.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.Networking.XboxLive.XboxLiveQualityOfServiceMeasurement: ...
    @winrt_mixinmethod
    def MeasureAsync(self: win32more.Windows.Networking.XboxLive.IXboxLiveQualityOfServiceMeasurement) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_mixinmethod
    def GetMetricResultsForDevice(self: win32more.Windows.Networking.XboxLive.IXboxLiveQualityOfServiceMeasurement, deviceAddress: win32more.Windows.Networking.XboxLive.XboxLiveDeviceAddress) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Networking.XboxLive.XboxLiveQualityOfServiceMetricResult]: ...
    @winrt_mixinmethod
    def GetMetricResultsForMetric(self: win32more.Windows.Networking.XboxLive.IXboxLiveQualityOfServiceMeasurement, metric: win32more.Windows.Networking.XboxLive.XboxLiveQualityOfServiceMetric) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Networking.XboxLive.XboxLiveQualityOfServiceMetricResult]: ...
    @winrt_mixinmethod
    def GetMetricResult(self: win32more.Windows.Networking.XboxLive.IXboxLiveQualityOfServiceMeasurement, deviceAddress: win32more.Windows.Networking.XboxLive.XboxLiveDeviceAddress, metric: win32more.Windows.Networking.XboxLive.XboxLiveQualityOfServiceMetric) -> win32more.Windows.Networking.XboxLive.XboxLiveQualityOfServiceMetricResult: ...
    @winrt_mixinmethod
    def GetPrivatePayloadResult(self: win32more.Windows.Networking.XboxLive.IXboxLiveQualityOfServiceMeasurement, deviceAddress: win32more.Windows.Networking.XboxLive.XboxLiveDeviceAddress) -> win32more.Windows.Networking.XboxLive.XboxLiveQualityOfServicePrivatePayloadResult: ...
    @winrt_mixinmethod
    def get_Metrics(self: win32more.Windows.Networking.XboxLive.IXboxLiveQualityOfServiceMeasurement) -> win32more.Windows.Foundation.Collections.IVector[win32more.Windows.Networking.XboxLive.XboxLiveQualityOfServiceMetric]: ...
    @winrt_mixinmethod
    def get_DeviceAddresses(self: win32more.Windows.Networking.XboxLive.IXboxLiveQualityOfServiceMeasurement) -> win32more.Windows.Foundation.Collections.IVector[win32more.Windows.Networking.XboxLive.XboxLiveDeviceAddress]: ...
    @winrt_mixinmethod
    def get_ShouldRequestPrivatePayloads(self: win32more.Windows.Networking.XboxLive.IXboxLiveQualityOfServiceMeasurement) -> Boolean: ...
    @winrt_mixinmethod
    def put_ShouldRequestPrivatePayloads(self: win32more.Windows.Networking.XboxLive.IXboxLiveQualityOfServiceMeasurement, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_TimeoutInMilliseconds(self: win32more.Windows.Networking.XboxLive.IXboxLiveQualityOfServiceMeasurement) -> UInt32: ...
    @winrt_mixinmethod
    def put_TimeoutInMilliseconds(self: win32more.Windows.Networking.XboxLive.IXboxLiveQualityOfServiceMeasurement, value: UInt32) -> Void: ...
    @winrt_mixinmethod
    def get_NumberOfProbesToAttempt(self: win32more.Windows.Networking.XboxLive.IXboxLiveQualityOfServiceMeasurement) -> UInt32: ...
    @winrt_mixinmethod
    def put_NumberOfProbesToAttempt(self: win32more.Windows.Networking.XboxLive.IXboxLiveQualityOfServiceMeasurement, value: UInt32) -> Void: ...
    @winrt_mixinmethod
    def get_NumberOfResultsPending(self: win32more.Windows.Networking.XboxLive.IXboxLiveQualityOfServiceMeasurement) -> UInt32: ...
    @winrt_mixinmethod
    def get_MetricResults(self: win32more.Windows.Networking.XboxLive.IXboxLiveQualityOfServiceMeasurement) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Networking.XboxLive.XboxLiveQualityOfServiceMetricResult]: ...
    @winrt_mixinmethod
    def get_PrivatePayloadResults(self: win32more.Windows.Networking.XboxLive.IXboxLiveQualityOfServiceMeasurement) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Networking.XboxLive.XboxLiveQualityOfServicePrivatePayloadResult]: ...
    @winrt_classmethod
    def PublishPrivatePayloadBytes(cls: win32more.Windows.Networking.XboxLive.IXboxLiveQualityOfServiceMeasurementStatics, payload: PassArray[Byte]) -> Void: ...
    @winrt_classmethod
    def ClearPrivatePayload(cls: win32more.Windows.Networking.XboxLive.IXboxLiveQualityOfServiceMeasurementStatics) -> Void: ...
    @winrt_classmethod
    def get_MaxSimultaneousProbeConnections(cls: win32more.Windows.Networking.XboxLive.IXboxLiveQualityOfServiceMeasurementStatics) -> UInt32: ...
    @winrt_classmethod
    def put_MaxSimultaneousProbeConnections(cls: win32more.Windows.Networking.XboxLive.IXboxLiveQualityOfServiceMeasurementStatics, value: UInt32) -> Void: ...
    @winrt_classmethod
    def get_IsSystemOutboundBandwidthConstrained(cls: win32more.Windows.Networking.XboxLive.IXboxLiveQualityOfServiceMeasurementStatics) -> Boolean: ...
    @winrt_classmethod
    def put_IsSystemOutboundBandwidthConstrained(cls: win32more.Windows.Networking.XboxLive.IXboxLiveQualityOfServiceMeasurementStatics, value: Boolean) -> Void: ...
    @winrt_classmethod
    def get_IsSystemInboundBandwidthConstrained(cls: win32more.Windows.Networking.XboxLive.IXboxLiveQualityOfServiceMeasurementStatics) -> Boolean: ...
    @winrt_classmethod
    def put_IsSystemInboundBandwidthConstrained(cls: win32more.Windows.Networking.XboxLive.IXboxLiveQualityOfServiceMeasurementStatics, value: Boolean) -> Void: ...
    @winrt_classmethod
    def get_PublishedPrivatePayload(cls: win32more.Windows.Networking.XboxLive.IXboxLiveQualityOfServiceMeasurementStatics) -> win32more.Windows.Storage.Streams.IBuffer: ...
    @winrt_classmethod
    def put_PublishedPrivatePayload(cls: win32more.Windows.Networking.XboxLive.IXboxLiveQualityOfServiceMeasurementStatics, value: win32more.Windows.Storage.Streams.IBuffer) -> Void: ...
    @winrt_classmethod
    def get_MaxPrivatePayloadSize(cls: win32more.Windows.Networking.XboxLive.IXboxLiveQualityOfServiceMeasurementStatics) -> UInt32: ...
    DeviceAddresses = property(get_DeviceAddresses, None)
    MetricResults = property(get_MetricResults, None)
    Metrics = property(get_Metrics, None)
    NumberOfProbesToAttempt = property(get_NumberOfProbesToAttempt, put_NumberOfProbesToAttempt)
    NumberOfResultsPending = property(get_NumberOfResultsPending, None)
    PrivatePayloadResults = property(get_PrivatePayloadResults, None)
    ShouldRequestPrivatePayloads = property(get_ShouldRequestPrivatePayloads, put_ShouldRequestPrivatePayloads)
    TimeoutInMilliseconds = property(get_TimeoutInMilliseconds, put_TimeoutInMilliseconds)
    _XboxLiveQualityOfServiceMeasurement_Meta_.IsSystemInboundBandwidthConstrained = property(get_IsSystemInboundBandwidthConstrained, put_IsSystemInboundBandwidthConstrained)
    _XboxLiveQualityOfServiceMeasurement_Meta_.IsSystemOutboundBandwidthConstrained = property(get_IsSystemOutboundBandwidthConstrained, put_IsSystemOutboundBandwidthConstrained)
    _XboxLiveQualityOfServiceMeasurement_Meta_.MaxPrivatePayloadSize = property(get_MaxPrivatePayloadSize, None)
    _XboxLiveQualityOfServiceMeasurement_Meta_.MaxSimultaneousProbeConnections = property(get_MaxSimultaneousProbeConnections, put_MaxSimultaneousProbeConnections)
    _XboxLiveQualityOfServiceMeasurement_Meta_.PublishedPrivatePayload = property(get_PublishedPrivatePayload, put_PublishedPrivatePayload)
class XboxLiveQualityOfServiceMeasurementStatus(Enum, Int32):
    NotStarted = 0
    InProgress = 1
    InProgressWithProvisionalResults = 2
    Succeeded = 3
    NoLocalNetworks = 4
    NoCompatibleNetworkPaths = 5
    LocalSystemNotAuthorized = 6
    Canceled = 7
    TimedOut = 8
    RemoteSystemNotAuthorized = 9
    RefusedDueToConfiguration = 10
    UnexpectedInternalError = 11
class XboxLiveQualityOfServiceMetric(Enum, Int32):
    AverageLatencyInMilliseconds = 0
    MinLatencyInMilliseconds = 1
    MaxLatencyInMilliseconds = 2
    AverageOutboundBitsPerSecond = 3
    MinOutboundBitsPerSecond = 4
    MaxOutboundBitsPerSecond = 5
    AverageInboundBitsPerSecond = 6
    MinInboundBitsPerSecond = 7
    MaxInboundBitsPerSecond = 8
class XboxLiveQualityOfServiceMetricResult(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Networking.XboxLive.IXboxLiveQualityOfServiceMetricResult
    _classid_ = 'Windows.Networking.XboxLive.XboxLiveQualityOfServiceMetricResult'
    @winrt_mixinmethod
    def get_Status(self: win32more.Windows.Networking.XboxLive.IXboxLiveQualityOfServiceMetricResult) -> win32more.Windows.Networking.XboxLive.XboxLiveQualityOfServiceMeasurementStatus: ...
    @winrt_mixinmethod
    def get_DeviceAddress(self: win32more.Windows.Networking.XboxLive.IXboxLiveQualityOfServiceMetricResult) -> win32more.Windows.Networking.XboxLive.XboxLiveDeviceAddress: ...
    @winrt_mixinmethod
    def get_Metric(self: win32more.Windows.Networking.XboxLive.IXboxLiveQualityOfServiceMetricResult) -> win32more.Windows.Networking.XboxLive.XboxLiveQualityOfServiceMetric: ...
    @winrt_mixinmethod
    def get_Value(self: win32more.Windows.Networking.XboxLive.IXboxLiveQualityOfServiceMetricResult) -> UInt64: ...
    DeviceAddress = property(get_DeviceAddress, None)
    Metric = property(get_Metric, None)
    Status = property(get_Status, None)
    Value = property(get_Value, None)
class XboxLiveQualityOfServicePrivatePayloadResult(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Networking.XboxLive.IXboxLiveQualityOfServicePrivatePayloadResult
    _classid_ = 'Windows.Networking.XboxLive.XboxLiveQualityOfServicePrivatePayloadResult'
    @winrt_mixinmethod
    def get_Status(self: win32more.Windows.Networking.XboxLive.IXboxLiveQualityOfServicePrivatePayloadResult) -> win32more.Windows.Networking.XboxLive.XboxLiveQualityOfServiceMeasurementStatus: ...
    @winrt_mixinmethod
    def get_DeviceAddress(self: win32more.Windows.Networking.XboxLive.IXboxLiveQualityOfServicePrivatePayloadResult) -> win32more.Windows.Networking.XboxLive.XboxLiveDeviceAddress: ...
    @winrt_mixinmethod
    def get_Value(self: win32more.Windows.Networking.XboxLive.IXboxLiveQualityOfServicePrivatePayloadResult) -> win32more.Windows.Storage.Streams.IBuffer: ...
    DeviceAddress = property(get_DeviceAddress, None)
    Status = property(get_Status, None)
    Value = property(get_Value, None)
XboxLiveSecureSocketsContract: UInt32 = 65536
class XboxLiveSocketKind(Enum, Int32):
    None_ = 0
    Datagram = 1
    Stream = 2


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.System.MixedReality
PERCEPTIONFIELD_StateStream_TimeStamps: Guid = Guid('{aa886119-f32f-49bf-92ca-f9ddf784d297}')
class PERCEPTION_PAYLOAD_FIELD(Structure):
    FieldId: Guid
    OffsetInBytes: UInt32
    SizeInBytes: UInt32
class PERCEPTION_STATE_STREAM_TIMESTAMPS(Structure):
    InputTimestampInQpcCounts: Int64
    AvailableTimestampInQpcCounts: Int64


make_ready(__name__)
